Class: Lockally::AdminFull
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::AdminFull
- Defined in:
- lib/lockally/models/admin_full.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#disabled ⇒ Object
Returns the value of attribute disabled.
-
#disabled_at ⇒ Object
Returns the value of attribute disabled_at.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#email ⇒ Object
Returns the value of attribute email.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_login_at ⇒ Object
Returns the value of attribute last_login_at.
-
#password ⇒ Object
Present ONLY on POST response when lockally generated the password.
-
#role ⇒ Object
Returns the value of attribute role.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdminFull
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdminFull
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/lockally/models/admin_full.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::AdminFull` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::AdminFull`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'last_login_at') self.last_login_at = attributes[:'last_login_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] else self.disabled = nil end if attributes.key?(:'disabled_at') self.disabled_at = attributes[:'disabled_at'] end if attributes.key?(:'password') self.password = attributes[:'password'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/lockally/models/admin_full.rb', line 30 def created_at @created_at end |
#disabled ⇒ Object
Returns the value of attribute disabled.
32 33 34 |
# File 'lib/lockally/models/admin_full.rb', line 32 def disabled @disabled end |
#disabled_at ⇒ Object
Returns the value of attribute disabled_at.
34 35 36 |
# File 'lib/lockally/models/admin_full.rb', line 34 def disabled_at @disabled_at end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/lockally/models/admin_full.rb', line 24 def display_name @display_name end |
#email ⇒ Object
Returns the value of attribute email.
22 23 24 |
# File 'lib/lockally/models/admin_full.rb', line 22 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/admin_full.rb', line 18 def id @id end |
#last_login_at ⇒ Object
Returns the value of attribute last_login_at.
28 29 30 |
# File 'lib/lockally/models/admin_full.rb', line 28 def last_login_at @last_login_at end |
#password ⇒ Object
Present ONLY on POST response when lockally generated the password. Shown once.
37 38 39 |
# File 'lib/lockally/models/admin_full.rb', line 37 def password @password end |
#role ⇒ Object
Returns the value of attribute role.
26 27 28 |
# File 'lib/lockally/models/admin_full.rb', line 26 def role @role end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
20 21 22 |
# File 'lib/lockally/models/admin_full.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/lockally/models/admin_full.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/lockally/models/admin_full.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/lockally/models/admin_full.rb', line 62 def self.attribute_map { :'id' => :'id', :'tenant_id' => :'tenant_id', :'email' => :'email', :'display_name' => :'display_name', :'role' => :'role', :'last_login_at' => :'last_login_at', :'created_at' => :'created_at', :'disabled' => :'disabled', :'disabled_at' => :'disabled_at', :'password' => :'password' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/lockally/models/admin_full.rb', line 324 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
110 111 112 113 114 |
# File 'lib/lockally/models/admin_full.rb', line 110 def self.openapi_all_of [ :'Admin' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/lockally/models/admin_full.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/lockally/models/admin_full.rb', line 88 def self.openapi_types { :'id' => :'String', :'tenant_id' => :'String', :'email' => :'String', :'display_name' => :'String', :'role' => :'String', :'last_login_at' => :'Time', :'created_at' => :'Time', :'disabled' => :'Boolean', :'disabled_at' => :'Time', :'password' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/lockally/models/admin_full.rb', line 294 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && tenant_id == o.tenant_id && email == o.email && display_name == o.display_name && role == o.role && last_login_at == o.last_login_at && created_at == o.created_at && disabled == o.disabled && disabled_at == o.disabled_at && password == o.password end |
#eql?(o) ⇒ Boolean
311 312 313 |
# File 'lib/lockally/models/admin_full.rb', line 311 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
317 318 319 |
# File 'lib/lockally/models/admin_full.rb', line 317 def hash [id, tenant_id, email, display_name, role, last_login_at, created_at, disabled, disabled_at, password].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/lockally/models/admin_full.rb', line 187 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @disabled.nil? invalid_properties.push('invalid value for "disabled", disabled cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/lockally/models/admin_full.rb', line 346 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/lockally/models/admin_full.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @tenant_id.nil? return false if @email.nil? return false if @role.nil? role_validator = EnumAttributeValidator.new('String', ["admin", "viewer"]) return false unless role_validator.valid?(@role) return false if @created_at.nil? return false if @disabled.nil? true end |