Class: Lockally::CalendarEvent

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/calendar_event.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CalendarEvent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/lockally/models/calendar_event.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::CalendarEvent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::CalendarEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'calendar_id')
    self.calendar_id = attributes[:'calendar_id']
  else
    self.calendar_id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  else
    self.uid = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'starts_at')
    self.starts_at = attributes[:'starts_at']
  else
    self.starts_at = nil
  end

  if attributes.key?(:'ends_at')
    self.ends_at = attributes[:'ends_at']
  else
    self.ends_at = nil
  end

  if attributes.key?(:'all_day')
    self.all_day = attributes[:'all_day']
  else
    self.all_day = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#all_dayObject

Returns the value of attribute all_day.



36
37
38
# File 'lib/lockally/models/calendar_event.rb', line 36

def all_day
  @all_day
end

#calendar_idObject

Returns the value of attribute calendar_id.



20
21
22
# File 'lib/lockally/models/calendar_event.rb', line 20

def calendar_id
  @calendar_id
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/lockally/models/calendar_event.rb', line 38

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



28
29
30
# File 'lib/lockally/models/calendar_event.rb', line 28

def description
  @description
end

#ends_atObject

Returns the value of attribute ends_at.



34
35
36
# File 'lib/lockally/models/calendar_event.rb', line 34

def ends_at
  @ends_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/calendar_event.rb', line 18

def id
  @id
end

#locationObject

Returns the value of attribute location.



30
31
32
# File 'lib/lockally/models/calendar_event.rb', line 30

def location
  @location
end

#starts_atObject

Returns the value of attribute starts_at.



32
33
34
# File 'lib/lockally/models/calendar_event.rb', line 32

def starts_at
  @starts_at
end

#tenant_idObject

Returns the value of attribute tenant_id.



22
23
24
# File 'lib/lockally/models/calendar_event.rb', line 22

def tenant_id
  @tenant_id
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/lockally/models/calendar_event.rb', line 26

def title
  @title
end

#uidObject

Returns the value of attribute uid.



24
25
26
# File 'lib/lockally/models/calendar_event.rb', line 24

def uid
  @uid
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/lockally/models/calendar_event.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/lockally/models/calendar_event.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/lockally/models/calendar_event.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/lockally/models/calendar_event.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'calendar_id' => :'calendar_id',
    :'tenant_id' => :'tenant_id',
    :'uid' => :'uid',
    :'title' => :'title',
    :'description' => :'description',
    :'location' => :'location',
    :'starts_at' => :'starts_at',
    :'ends_at' => :'ends_at',
    :'all_day' => :'all_day',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/lockally/models/calendar_event.rb', line 378

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/lockally/models/calendar_event.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/lockally/models/calendar_event.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'calendar_id' => :'String',
    :'tenant_id' => :'String',
    :'uid' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'location' => :'String',
    :'starts_at' => :'Time',
    :'ends_at' => :'Time',
    :'all_day' => :'Boolean',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/lockally/models/calendar_event.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      calendar_id == o.calendar_id &&
      tenant_id == o.tenant_id &&
      uid == o.uid &&
      title == o.title &&
      description == o.description &&
      location == o.location &&
      starts_at == o.starts_at &&
      ends_at == o.ends_at &&
      all_day == o.all_day &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


365
366
367
# File 'lib/lockally/models/calendar_event.rb', line 365

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



371
372
373
# File 'lib/lockally/models/calendar_event.rb', line 371

def hash
  [id, calendar_id, tenant_id, uid, title, description, location, starts_at, ends_at, all_day, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/lockally/models/calendar_event.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @calendar_id.nil?
    invalid_properties.push('invalid value for "calendar_id", calendar_id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @uid.nil?
    invalid_properties.push('invalid value for "uid", uid cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @starts_at.nil?
    invalid_properties.push('invalid value for "starts_at", starts_at cannot be nil.')
  end

  if @ends_at.nil?
    invalid_properties.push('invalid value for "ends_at", ends_at cannot be nil.')
  end

  if @all_day.nil?
    invalid_properties.push('invalid value for "all_day", all_day cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/lockally/models/calendar_event.rb', line 400

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/lockally/models/calendar_event.rb', line 229

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @calendar_id.nil?
  return false if @tenant_id.nil?
  return false if @uid.nil?
  return false if @title.nil?
  return false if @starts_at.nil?
  return false if @ends_at.nil?
  return false if @all_day.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end