Class: Lockally::CalendarIntegration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::CalendarIntegration
- Defined in:
- lib/lockally/models/calendar_integration.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#id ⇒ Object
Returns the value of attribute id.
-
#label ⇒ Object
Returns the value of attribute label.
-
#last_sync_at ⇒ Object
Returns the value of attribute last_sync_at.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CalendarIntegration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CalendarIntegration
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/lockally/models/calendar_integration.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::CalendarIntegration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::CalendarIntegration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'last_sync_at') self.last_sync_at = attributes[:'last_sync_at'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
32 33 34 |
# File 'lib/lockally/models/calendar_integration.rb', line 32 def created_at @created_at end |
#error_message ⇒ Object
Returns the value of attribute error_message.
30 31 32 |
# File 'lib/lockally/models/calendar_integration.rb', line 30 def @error_message end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/calendar_integration.rb', line 18 def id @id end |
#label ⇒ Object
Returns the value of attribute label.
24 25 26 |
# File 'lib/lockally/models/calendar_integration.rb', line 24 def label @label end |
#last_sync_at ⇒ Object
Returns the value of attribute last_sync_at.
28 29 30 |
# File 'lib/lockally/models/calendar_integration.rb', line 28 def last_sync_at @last_sync_at end |
#provider ⇒ Object
Returns the value of attribute provider.
22 23 24 |
# File 'lib/lockally/models/calendar_integration.rb', line 22 def provider @provider end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/lockally/models/calendar_integration.rb', line 26 def status @status end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
20 21 22 |
# File 'lib/lockally/models/calendar_integration.rb', line 20 def tenant_id @tenant_id end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
34 35 36 |
# File 'lib/lockally/models/calendar_integration.rb', line 34 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/lockally/models/calendar_integration.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/lockally/models/calendar_integration.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/lockally/models/calendar_integration.rb', line 59 def self.attribute_map { :'id' => :'id', :'tenant_id' => :'tenant_id', :'provider' => :'provider', :'label' => :'label', :'status' => :'status', :'last_sync_at' => :'last_sync_at', :'error_message' => :'error_message', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/lockally/models/calendar_integration.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/lockally/models/calendar_integration.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/lockally/models/calendar_integration.rb', line 84 def self.openapi_types { :'id' => :'String', :'tenant_id' => :'String', :'provider' => :'String', :'label' => :'String', :'status' => :'String', :'last_sync_at' => :'Time', :'error_message' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/lockally/models/calendar_integration.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && tenant_id == o.tenant_id && provider == o.provider && label == o.label && status == o.status && last_sync_at == o.last_sync_at && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/lockally/models/calendar_integration.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/lockally/models/calendar_integration.rb', line 302 def hash [id, tenant_id, provider, label, status, last_sync_at, , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/lockally/models/calendar_integration.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/lockally/models/calendar_integration.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/lockally/models/calendar_integration.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @tenant_id.nil? return false if @provider.nil? provider_validator = EnumAttributeValidator.new('String', ["exchange", "google_calendar", "teams", "zoom", "erp"]) return false unless provider_validator.valid?(@provider) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["connected", "disconnected", "error", "syncing"]) return false unless status_validator.valid?(@status) return false if @created_at.nil? return false if @updated_at.nil? true end |