Class: Lockally::GALSettings
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::GALSettings
- Defined in:
- lib/lockally/models/gal_settings.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#department_grouping ⇒ Object
Returns the value of attribute department_grouping.
-
#gal_enabled ⇒ Object
Returns the value of attribute gal_enabled.
-
#hide_from_directory ⇒ Object
Returns the value of attribute hide_from_directory.
-
#include_external_contacts ⇒ Object
Returns the value of attribute include_external_contacts.
-
#last_index_rebuilt_at ⇒ Object
Returns the value of attribute last_index_rebuilt_at.
-
#last_synced_at ⇒ Object
Returns the value of attribute last_synced_at.
-
#search_visibility ⇒ Object
Returns the value of attribute search_visibility.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GALSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GALSettings
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/lockally/models/gal_settings.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::GALSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::GALSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'gal_enabled') self.gal_enabled = attributes[:'gal_enabled'] else self.gal_enabled = nil end if attributes.key?(:'hide_from_directory') self.hide_from_directory = attributes[:'hide_from_directory'] else self.hide_from_directory = nil end if attributes.key?(:'department_grouping') self.department_grouping = attributes[:'department_grouping'] else self.department_grouping = nil end if attributes.key?(:'search_visibility') self.search_visibility = attributes[:'search_visibility'] else self.search_visibility = nil end if attributes.key?(:'include_external_contacts') self.include_external_contacts = attributes[:'include_external_contacts'] else self.include_external_contacts = nil end if attributes.key?(:'last_index_rebuilt_at') self.last_index_rebuilt_at = attributes[:'last_index_rebuilt_at'] end if attributes.key?(:'last_synced_at') self.last_synced_at = attributes[:'last_synced_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/lockally/models/gal_settings.rb', line 34 def created_at @created_at end |
#department_grouping ⇒ Object
Returns the value of attribute department_grouping.
24 25 26 |
# File 'lib/lockally/models/gal_settings.rb', line 24 def department_grouping @department_grouping end |
#gal_enabled ⇒ Object
Returns the value of attribute gal_enabled.
20 21 22 |
# File 'lib/lockally/models/gal_settings.rb', line 20 def gal_enabled @gal_enabled end |
#hide_from_directory ⇒ Object
Returns the value of attribute hide_from_directory.
22 23 24 |
# File 'lib/lockally/models/gal_settings.rb', line 22 def hide_from_directory @hide_from_directory end |
#include_external_contacts ⇒ Object
Returns the value of attribute include_external_contacts.
28 29 30 |
# File 'lib/lockally/models/gal_settings.rb', line 28 def include_external_contacts @include_external_contacts end |
#last_index_rebuilt_at ⇒ Object
Returns the value of attribute last_index_rebuilt_at.
30 31 32 |
# File 'lib/lockally/models/gal_settings.rb', line 30 def last_index_rebuilt_at @last_index_rebuilt_at end |
#last_synced_at ⇒ Object
Returns the value of attribute last_synced_at.
32 33 34 |
# File 'lib/lockally/models/gal_settings.rb', line 32 def last_synced_at @last_synced_at end |
#search_visibility ⇒ Object
Returns the value of attribute search_visibility.
26 27 28 |
# File 'lib/lockally/models/gal_settings.rb', line 26 def search_visibility @search_visibility end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
18 19 20 |
# File 'lib/lockally/models/gal_settings.rb', line 18 def tenant_id @tenant_id end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/lockally/models/gal_settings.rb', line 36 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/lockally/models/gal_settings.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/lockally/models/gal_settings.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/lockally/models/gal_settings.rb', line 61 def self.attribute_map { :'tenant_id' => :'tenant_id', :'gal_enabled' => :'gal_enabled', :'hide_from_directory' => :'hide_from_directory', :'department_grouping' => :'department_grouping', :'search_visibility' => :'search_visibility', :'include_external_contacts' => :'include_external_contacts', :'last_index_rebuilt_at' => :'last_index_rebuilt_at', :'last_synced_at' => :'last_synced_at', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/lockally/models/gal_settings.rb', line 316 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/lockally/models/gal_settings.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/lockally/models/gal_settings.rb', line 87 def self.openapi_types { :'tenant_id' => :'String', :'gal_enabled' => :'Boolean', :'hide_from_directory' => :'Boolean', :'department_grouping' => :'Boolean', :'search_visibility' => :'String', :'include_external_contacts' => :'Boolean', :'last_index_rebuilt_at' => :'Time', :'last_synced_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/lockally/models/gal_settings.rb', line 286 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && gal_enabled == o.gal_enabled && hide_from_directory == o.hide_from_directory && department_grouping == o.department_grouping && search_visibility == o.search_visibility && include_external_contacts == o.include_external_contacts && last_index_rebuilt_at == o.last_index_rebuilt_at && last_synced_at == o.last_synced_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/lockally/models/gal_settings.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/lockally/models/gal_settings.rb', line 309 def hash [tenant_id, gal_enabled, hide_from_directory, department_grouping, search_visibility, include_external_contacts, last_index_rebuilt_at, last_synced_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/lockally/models/gal_settings.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @gal_enabled.nil? invalid_properties.push('invalid value for "gal_enabled", gal_enabled cannot be nil.') end if @hide_from_directory.nil? invalid_properties.push('invalid value for "hide_from_directory", hide_from_directory cannot be nil.') end if @department_grouping.nil? invalid_properties.push('invalid value for "department_grouping", department_grouping cannot be nil.') end if @search_visibility.nil? invalid_properties.push('invalid value for "search_visibility", search_visibility cannot be nil.') end if @include_external_contacts.nil? invalid_properties.push('invalid value for "include_external_contacts", include_external_contacts cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/lockally/models/gal_settings.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/lockally/models/gal_settings.rb', line 211 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tenant_id.nil? return false if @gal_enabled.nil? return false if @hide_from_directory.nil? return false if @department_grouping.nil? return false if @search_visibility.nil? search_visibility_validator = EnumAttributeValidator.new('String', ["all_users", "same_department", "admins_only"]) return false unless search_visibility_validator.valid?(@search_visibility) return false if @include_external_contacts.nil? true end |