Class: Lockally::GetAuditSummary200Response

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/get_audit_summary200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAuditSummary200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::GetAuditSummary200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::GetAuditSummary200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_actions_today')
    self.admin_actions_today = attributes[:'admin_actions_today']
  end

  if attributes.key?(:'recent_logins')
    if (value = attributes[:'recent_logins']).is_a?(Array)
      self.recent_logins = value
    end
  end

  if attributes.key?(:'recent_exports')
    if (value = attributes[:'recent_exports']).is_a?(Array)
      self.recent_exports = value
    end
  end

  if attributes.key?(:'deleted_mailboxes')
    if (value = attributes[:'deleted_mailboxes']).is_a?(Array)
      self.deleted_mailboxes = value
    end
  end

  if attributes.key?(:'generated_at')
    self.generated_at = attributes[:'generated_at']
  end
end

Instance Attribute Details

#admin_actions_todayObject

Returns the value of attribute admin_actions_today.



18
19
20
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 18

def admin_actions_today
  @admin_actions_today
end

#deleted_mailboxesObject

Returns the value of attribute deleted_mailboxes.



24
25
26
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 24

def deleted_mailboxes
  @deleted_mailboxes
end

#generated_atObject

Returns the value of attribute generated_at.



26
27
28
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 26

def generated_at
  @generated_at
end

#recent_exportsObject

Returns the value of attribute recent_exports.



22
23
24
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 22

def recent_exports
  @recent_exports
end

#recent_loginsObject

Returns the value of attribute recent_logins.



20
21
22
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 20

def recent_logins
  @recent_logins
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 29

def self.attribute_map
  {
    :'admin_actions_today' => :'admin_actions_today',
    :'recent_logins' => :'recent_logins',
    :'recent_exports' => :'recent_exports',
    :'deleted_mailboxes' => :'deleted_mailboxes',
    :'generated_at' => :'generated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 50

def self.openapi_types
  {
    :'admin_actions_today' => :'Integer',
    :'recent_logins' => :'Array<AuditEvent>',
    :'recent_exports' => :'Array<AuditEvent>',
    :'deleted_mailboxes' => :'Array<AuditEvent>',
    :'generated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_actions_today == o.admin_actions_today &&
      recent_logins == o.recent_logins &&
      recent_exports == o.recent_exports &&
      deleted_mailboxes == o.deleted_mailboxes &&
      generated_at == o.generated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 138

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 144

def hash
  [admin_actions_today, recent_logins, recent_exports, deleted_mailboxes, generated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
# File 'lib/lockally/models/get_audit_summary200_response.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end