Class: Lockally::HealthApi
- Inherits:
-
Object
- Object
- Lockally::HealthApi
- Defined in:
- lib/lockally/api/health_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#healthz_get(opts = {}) ⇒ HealthzGet200Response
Liveness check Returns 200 if the process is up and the database pings cleanly.
-
#healthz_get_with_http_info(opts = {}) ⇒ Array<(HealthzGet200Response, Integer, Hash)>
Liveness check Returns 200 if the process is up and the database pings cleanly.
-
#initialize(api_client = ApiClient.default) ⇒ HealthApi
constructor
A new instance of HealthApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lockally/api/health_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#healthz_get(opts = {}) ⇒ HealthzGet200Response
Liveness check Returns 200 if the process is up and the database pings cleanly. No authentication required.
26 27 28 29 |
# File 'lib/lockally/api/health_api.rb', line 26 def healthz_get(opts = {}) data, _status_code, _headers = healthz_get_with_http_info(opts) data end |
#healthz_get_with_http_info(opts = {}) ⇒ Array<(HealthzGet200Response, Integer, Hash)>
Liveness check Returns 200 if the process is up and the database pings cleanly. No authentication required.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lockally/api/health_api.rb', line 35 def healthz_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HealthApi.healthz_get ...' end # resource path local_var_path = '/healthz' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'HealthzGet200Response' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"HealthApi.healthz_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HealthApi#healthz_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |