Class: Lockally::Mailbox

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/mailbox.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Mailbox

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/lockally/models/mailbox.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Mailbox` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Mailbox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'domain_id')
    self.domain_id = attributes[:'domain_id']
  else
    self.domain_id = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'quota_bytes')
    self.quota_bytes = attributes[:'quota_bytes']
  else
    self.quota_bytes = nil
  end

  if attributes.key?(:'disabled')
    self.disabled = attributes[:'disabled']
  else
    self.disabled = nil
  end

  if attributes.key?(:'disabled_at')
    self.disabled_at = attributes[:'disabled_at']
  end

  if attributes.key?(:'soft_deleted_at')
    self.soft_deleted_at = attributes[:'soft_deleted_at']
  end

  if attributes.key?(:'hard_delete_after')
    self.hard_delete_after = attributes[:'hard_delete_after']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/lockally/models/mailbox.rb', line 36

def created_at
  @created_at
end

#disabledObject

Returns the value of attribute disabled.



28
29
30
# File 'lib/lockally/models/mailbox.rb', line 28

def disabled
  @disabled
end

#disabled_atObject

Returns the value of attribute disabled_at.



30
31
32
# File 'lib/lockally/models/mailbox.rb', line 30

def disabled_at
  @disabled_at
end

#domain_idObject

Returns the value of attribute domain_id.



22
23
24
# File 'lib/lockally/models/mailbox.rb', line 22

def domain_id
  @domain_id
end

#emailObject

Returns the value of attribute email.



24
25
26
# File 'lib/lockally/models/mailbox.rb', line 24

def email
  @email
end

#hard_delete_afterObject

Returns the value of attribute hard_delete_after.



34
35
36
# File 'lib/lockally/models/mailbox.rb', line 34

def hard_delete_after
  @hard_delete_after
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/mailbox.rb', line 18

def id
  @id
end

#passwordObject

ONLY present on POST response when lockally generated the password. Shown once.



39
40
41
# File 'lib/lockally/models/mailbox.rb', line 39

def password
  @password
end

#quota_bytesObject

Returns the value of attribute quota_bytes.



26
27
28
# File 'lib/lockally/models/mailbox.rb', line 26

def quota_bytes
  @quota_bytes
end

#soft_deleted_atObject

Returns the value of attribute soft_deleted_at.



32
33
34
# File 'lib/lockally/models/mailbox.rb', line 32

def soft_deleted_at
  @soft_deleted_at
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/lockally/models/mailbox.rb', line 20

def tenant_id
  @tenant_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/lockally/models/mailbox.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/lockally/models/mailbox.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/lockally/models/mailbox.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'tenant_id' => :'tenant_id',
    :'domain_id' => :'domain_id',
    :'email' => :'email',
    :'quota_bytes' => :'quota_bytes',
    :'disabled' => :'disabled',
    :'disabled_at' => :'disabled_at',
    :'soft_deleted_at' => :'soft_deleted_at',
    :'hard_delete_after' => :'hard_delete_after',
    :'created_at' => :'created_at',
    :'password' => :'password'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/lockally/models/mailbox.rb', line 319

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/lockally/models/mailbox.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/lockally/models/mailbox.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'tenant_id' => :'String',
    :'domain_id' => :'String',
    :'email' => :'String',
    :'quota_bytes' => :'Integer',
    :'disabled' => :'Boolean',
    :'disabled_at' => :'Time',
    :'soft_deleted_at' => :'Time',
    :'hard_delete_after' => :'Time',
    :'created_at' => :'Time',
    :'password' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/lockally/models/mailbox.rb', line 288

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      tenant_id == o.tenant_id &&
      domain_id == o.domain_id &&
      email == o.email &&
      quota_bytes == o.quota_bytes &&
      disabled == o.disabled &&
      disabled_at == o.disabled_at &&
      soft_deleted_at == o.soft_deleted_at &&
      hard_delete_after == o.hard_delete_after &&
      created_at == o.created_at &&
      password == o.password
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/lockally/models/mailbox.rb', line 306

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



312
313
314
# File 'lib/lockally/models/mailbox.rb', line 312

def hash
  [id, tenant_id, domain_id, email, quota_bytes, disabled, disabled_at, soft_deleted_at, hard_delete_after, created_at, password].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/lockally/models/mailbox.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @domain_id.nil?
    invalid_properties.push('invalid value for "domain_id", domain_id cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @quota_bytes.nil?
    invalid_properties.push('invalid value for "quota_bytes", quota_bytes cannot be nil.')
  end

  if @disabled.nil?
    invalid_properties.push('invalid value for "disabled", disabled cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/lockally/models/mailbox.rb', line 341

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
211
212
213
214
# File 'lib/lockally/models/mailbox.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @tenant_id.nil?
  return false if @domain_id.nil?
  return false if @email.nil?
  return false if @quota_bytes.nil?
  return false if @disabled.nil?
  return false if @created_at.nil?
  true
end