Class: Lockally::Message

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Message

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/lockally/models/message.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Message` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Message`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  else
    self.message_id = nil
  end

  if attributes.key?(:'sender')
    self.sender = attributes[:'sender']
  else
    self.sender = nil
  end

  if attributes.key?(:'recipients')
    if (value = attributes[:'recipients']).is_a?(Array)
      self.recipients = value
    end
  else
    self.recipients = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'queued_at')
    self.queued_at = attributes[:'queued_at']
  else
    self.queued_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'bounce_reason')
    self.bounce_reason = attributes[:'bounce_reason']
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  end
end

Instance Attribute Details

#bounce_reasonObject

Returns the value of attribute bounce_reason.



37
38
39
# File 'lib/lockally/models/message.rb', line 37

def bounce_reason
  @bounce_reason
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/message.rb', line 18

def id
  @id
end

#message_idObject

RFC 5322 Message-ID header, including angle brackets.



23
24
25
# File 'lib/lockally/models/message.rb', line 23

def message_id
  @message_id
end

#queued_atObject

Returns the value of attribute queued_at.



33
34
35
# File 'lib/lockally/models/message.rb', line 33

def queued_at
  @queued_at
end

#recipientsObject

Returns the value of attribute recipients.



27
28
29
# File 'lib/lockally/models/message.rb', line 27

def recipients
  @recipients
end

#senderObject

Returns the value of attribute sender.



25
26
27
# File 'lib/lockally/models/message.rb', line 25

def sender
  @sender
end

#size_bytesObject

Returns the value of attribute size_bytes.



39
40
41
# File 'lib/lockally/models/message.rb', line 39

def size_bytes
  @size_bytes
end

#statusObject

Returns the value of attribute status.



31
32
33
# File 'lib/lockally/models/message.rb', line 31

def status
  @status
end

#subjectObject

Returns the value of attribute subject.



29
30
31
# File 'lib/lockally/models/message.rb', line 29

def subject
  @subject
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/lockally/models/message.rb', line 20

def tenant_id
  @tenant_id
end

#updated_atObject

Returns the value of attribute updated_at.



35
36
37
# File 'lib/lockally/models/message.rb', line 35

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/lockally/models/message.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/lockally/models/message.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/lockally/models/message.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'tenant_id' => :'tenant_id',
    :'message_id' => :'message_id',
    :'sender' => :'sender',
    :'recipients' => :'recipients',
    :'subject' => :'subject',
    :'status' => :'status',
    :'queued_at' => :'queued_at',
    :'updated_at' => :'updated_at',
    :'bounce_reason' => :'bounce_reason',
    :'size_bytes' => :'size_bytes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/lockally/models/message.rb', line 362

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/lockally/models/message.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/lockally/models/message.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'tenant_id' => :'String',
    :'message_id' => :'String',
    :'sender' => :'String',
    :'recipients' => :'Array<String>',
    :'subject' => :'String',
    :'status' => :'String',
    :'queued_at' => :'Time',
    :'updated_at' => :'Time',
    :'bounce_reason' => :'String',
    :'size_bytes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/lockally/models/message.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      tenant_id == o.tenant_id &&
      message_id == o.message_id &&
      sender == o.sender &&
      recipients == o.recipients &&
      subject == o.subject &&
      status == o.status &&
      queued_at == o.queued_at &&
      updated_at == o.updated_at &&
      bounce_reason == o.bounce_reason &&
      size_bytes == o.size_bytes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/lockally/models/message.rb', line 349

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



355
356
357
# File 'lib/lockally/models/message.rb', line 355

def hash
  [id, tenant_id, message_id, sender, recipients, subject, status, queued_at, updated_at, bounce_reason, size_bytes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/lockally/models/message.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @message_id.nil?
    invalid_properties.push('invalid value for "message_id", message_id cannot be nil.')
  end

  if @sender.nil?
    invalid_properties.push('invalid value for "sender", sender cannot be nil.')
  end

  if @recipients.nil?
    invalid_properties.push('invalid value for "recipients", recipients cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @queued_at.nil?
    invalid_properties.push('invalid value for "queued_at", queued_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/lockally/models/message.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/lockally/models/message.rb', line 234

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @tenant_id.nil?
  return false if @message_id.nil?
  return false if @sender.nil?
  return false if @recipients.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["queued", "sending", "delivered", "bounced", "deferred", "complaint"])
  return false unless status_validator.valid?(@status)
  return false if @queued_at.nil?
  return false if @updated_at.nil?
  true
end