Class: Lockally::Migration

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/migration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Migration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/lockally/models/migration.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Migration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Migration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'credential_id')
    self.credential_id = attributes[:'credential_id']
  else
    self.credential_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'source_provider')
    self.source_provider = attributes[:'source_provider']
  else
    self.source_provider = nil
  end

  if attributes.key?(:'source_summary')
    self.source_summary = attributes[:'source_summary']
  end

  if attributes.key?(:'settings')
    self.settings = attributes[:'settings']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'mailbox_count')
    self.mailbox_count = attributes[:'mailbox_count']
  else
    self.mailbox_count = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



38
39
40
# File 'lib/lockally/models/migration.rb', line 38

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/lockally/models/migration.rb', line 42

def created_at
  @created_at
end

#credential_idObject

Returns the value of attribute credential_id.



22
23
24
# File 'lib/lockally/models/migration.rb', line 22

def credential_id
  @credential_id
end

#error_messageObject

Returns the value of attribute error_message.



34
35
36
# File 'lib/lockally/models/migration.rb', line 34

def error_message
  @error_message
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/migration.rb', line 18

def id
  @id
end

#mailbox_countObject

Returns the value of attribute mailbox_count.



40
41
42
# File 'lib/lockally/models/migration.rb', line 40

def mailbox_count
  @mailbox_count
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/lockally/models/migration.rb', line 24

def name
  @name
end

#settingsObject

Returns the value of attribute settings.



32
33
34
# File 'lib/lockally/models/migration.rb', line 32

def settings
  @settings
end

#source_providerObject

Returns the value of attribute source_provider.



28
29
30
# File 'lib/lockally/models/migration.rb', line 28

def source_provider
  @source_provider
end

#source_summaryObject

Returns the value of attribute source_summary.



30
31
32
# File 'lib/lockally/models/migration.rb', line 30

def source_summary
  @source_summary
end

#started_atObject

Returns the value of attribute started_at.



36
37
38
# File 'lib/lockally/models/migration.rb', line 36

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/lockally/models/migration.rb', line 26

def status
  @status
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/lockally/models/migration.rb', line 20

def tenant_id
  @tenant_id
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/lockally/models/migration.rb', line 44

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/lockally/models/migration.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/lockally/models/migration.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/lockally/models/migration.rb', line 69

def self.attribute_map
  {
    :'id' => :'id',
    :'tenant_id' => :'tenant_id',
    :'credential_id' => :'credential_id',
    :'name' => :'name',
    :'status' => :'status',
    :'source_provider' => :'source_provider',
    :'source_summary' => :'source_summary',
    :'settings' => :'settings',
    :'error_message' => :'error_message',
    :'started_at' => :'started_at',
    :'completed_at' => :'completed_at',
    :'mailbox_count' => :'mailbox_count',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/lockally/models/migration.rb', line 403

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/lockally/models/migration.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/lockally/models/migration.rb', line 99

def self.openapi_types
  {
    :'id' => :'String',
    :'tenant_id' => :'String',
    :'credential_id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'source_provider' => :'String',
    :'source_summary' => :'String',
    :'settings' => :'MigrationSettings',
    :'error_message' => :'String',
    :'started_at' => :'Time',
    :'completed_at' => :'Time',
    :'mailbox_count' => :'Integer',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/lockally/models/migration.rb', line 369

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      tenant_id == o.tenant_id &&
      credential_id == o.credential_id &&
      name == o.name &&
      status == o.status &&
      source_provider == o.source_provider &&
      source_summary == o.source_summary &&
      settings == o.settings &&
      error_message == o.error_message &&
      started_at == o.started_at &&
      completed_at == o.completed_at &&
      mailbox_count == o.mailbox_count &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


390
391
392
# File 'lib/lockally/models/migration.rb', line 390

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



396
397
398
# File 'lib/lockally/models/migration.rb', line 396

def hash
  [id, tenant_id, credential_id, name, status, source_provider, source_summary, settings, error_message, started_at, completed_at, mailbox_count, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/lockally/models/migration.rb', line 217

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @credential_id.nil?
    invalid_properties.push('invalid value for "credential_id", credential_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @source_provider.nil?
    invalid_properties.push('invalid value for "source_provider", source_provider cannot be nil.')
  end

  if @mailbox_count.nil?
    invalid_properties.push('invalid value for "mailbox_count", mailbox_count cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/lockally/models/migration.rb', line 425

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/lockally/models/migration.rb', line 261

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @tenant_id.nil?
  return false if @credential_id.nil?
  return false if @name.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["draft", "discovering", "discovered", "mapped", "pilot_running", "pilot_complete", "running", "staged", "cutover_pending", "final_syncing", "validating", "completed", "failed", "cancelled"])
  return false unless status_validator.valid?(@status)
  return false if @source_provider.nil?
  return false if @mailbox_count.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end