Class: Lockally::MigrationProgressMailboxesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::MigrationProgressMailboxesInner
- Defined in:
- lib/lockally/models/migration_progress_mailboxes_inner.rb
Instance Attribute Summary collapse
-
#dest_email ⇒ Object
Returns the value of attribute dest_email.
-
#failed_message_count ⇒ Object
Returns the value of attribute failed_message_count.
-
#percent_complete ⇒ Object
Returns the value of attribute percent_complete.
-
#source_email ⇒ Object
Returns the value of attribute source_email.
-
#source_message_count ⇒ Object
Returns the value of attribute source_message_count.
-
#status ⇒ Object
Returns the value of attribute status.
-
#synced_message_count ⇒ Object
Returns the value of attribute synced_message_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MigrationProgressMailboxesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MigrationProgressMailboxesInner
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::MigrationProgressMailboxesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::MigrationProgressMailboxesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source_email') self.source_email = attributes[:'source_email'] else self.source_email = nil end if attributes.key?(:'dest_email') self.dest_email = attributes[:'dest_email'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'source_message_count') self. = attributes[:'source_message_count'] end if attributes.key?(:'synced_message_count') self. = attributes[:'synced_message_count'] else self. = nil end if attributes.key?(:'failed_message_count') self. = attributes[:'failed_message_count'] else self. = nil end if attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] else self.percent_complete = nil end end |
Instance Attribute Details
#dest_email ⇒ Object
Returns the value of attribute dest_email.
20 21 22 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 20 def dest_email @dest_email end |
#failed_message_count ⇒ Object
Returns the value of attribute failed_message_count.
28 29 30 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 28 def @failed_message_count end |
#percent_complete ⇒ Object
Returns the value of attribute percent_complete.
30 31 32 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 30 def percent_complete @percent_complete end |
#source_email ⇒ Object
Returns the value of attribute source_email.
18 19 20 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 18 def source_email @source_email end |
#source_message_count ⇒ Object
Returns the value of attribute source_message_count.
24 25 26 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 24 def @source_message_count end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 22 def status @status end |
#synced_message_count ⇒ Object
Returns the value of attribute synced_message_count.
26 27 28 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 26 def @synced_message_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 33 def self.attribute_map { :'source_email' => :'source_email', :'dest_email' => :'dest_email', :'status' => :'status', :'source_message_count' => :'source_message_count', :'synced_message_count' => :'synced_message_count', :'failed_message_count' => :'failed_message_count', :'percent_complete' => :'percent_complete' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 248 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 56 def self.openapi_types { :'source_email' => :'String', :'dest_email' => :'String', :'status' => :'String', :'source_message_count' => :'Integer', :'synced_message_count' => :'Integer', :'failed_message_count' => :'Integer', :'percent_complete' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && source_email == o.source_email && dest_email == o.dest_email && status == o.status && == o. && == o. && == o. && percent_complete == o.percent_complete end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 241 def hash [source_email, dest_email, status, , , , percent_complete].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @source_email.nil? invalid_properties.push('invalid value for "source_email", source_email cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @synced_message_count.nil? invalid_properties.push('invalid value for "synced_message_count", synced_message_count cannot be nil.') end if @failed_message_count.nil? invalid_properties.push('invalid value for "failed_message_count", failed_message_count cannot be nil.') end if @percent_complete.nil? invalid_properties.push('invalid value for "percent_complete", percent_complete cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 165 166 167 |
# File 'lib/lockally/models/migration_progress_mailboxes_inner.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @source_email.nil? return false if @status.nil? return false if @synced_message_count.nil? return false if @failed_message_count.nil? return false if @percent_complete.nil? true end |