Class: Lockally::PlanCatalogEntry
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::PlanCatalogEntry
- Defined in:
- lib/lockally/models/plan_catalog_entry.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#has_ai_units ⇒ Object
Returns the value of attribute has_ai_units.
-
#has_e2e_encryption ⇒ Object
Returns the value of attribute has_e2e_encryption.
-
#has_send_units ⇒ Object
Returns the value of attribute has_send_units.
-
#has_shared_mailboxes ⇒ Object
Returns the value of attribute has_shared_mailboxes.
-
#monthly_included_sends ⇒ Object
Returns the value of attribute monthly_included_sends.
-
#name ⇒ Object
Returns the value of attribute name.
-
#price_naira_per_seat ⇒ Object
Returns the value of attribute price_naira_per_seat.
-
#rate_cap_per_min ⇒ Object
Returns the value of attribute rate_cap_per_min.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlanCatalogEntry
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlanCatalogEntry
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::PlanCatalogEntry` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::PlanCatalogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] else self.display_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'price_naira_per_seat') self.price_naira_per_seat = attributes[:'price_naira_per_seat'] else self.price_naira_per_seat = nil end if attributes.key?(:'rate_cap_per_min') self.rate_cap_per_min = attributes[:'rate_cap_per_min'] else self.rate_cap_per_min = nil end if attributes.key?(:'monthly_included_sends') self.monthly_included_sends = attributes[:'monthly_included_sends'] else self.monthly_included_sends = nil end if attributes.key?(:'has_shared_mailboxes') self.has_shared_mailboxes = attributes[:'has_shared_mailboxes'] else self.has_shared_mailboxes = nil end if attributes.key?(:'has_send_units') self.has_send_units = attributes[:'has_send_units'] else self.has_send_units = nil end if attributes.key?(:'has_ai_units') self.has_ai_units = attributes[:'has_ai_units'] else self.has_ai_units = nil end if attributes.key?(:'has_e2e_encryption') self.has_e2e_encryption = attributes[:'has_e2e_encryption'] else self.has_e2e_encryption = nil end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 22 def description @description end |
#display_name ⇒ Object
Returns the value of attribute display_name.
20 21 22 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 20 def display_name @display_name end |
#has_ai_units ⇒ Object
Returns the value of attribute has_ai_units.
34 35 36 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 34 def has_ai_units @has_ai_units end |
#has_e2e_encryption ⇒ Object
Returns the value of attribute has_e2e_encryption.
36 37 38 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 36 def has_e2e_encryption @has_e2e_encryption end |
#has_send_units ⇒ Object
Returns the value of attribute has_send_units.
32 33 34 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 32 def has_send_units @has_send_units end |
#has_shared_mailboxes ⇒ Object
Returns the value of attribute has_shared_mailboxes.
30 31 32 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 30 def has_shared_mailboxes @has_shared_mailboxes end |
#monthly_included_sends ⇒ Object
Returns the value of attribute monthly_included_sends.
28 29 30 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 28 def monthly_included_sends @monthly_included_sends end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 18 def name @name end |
#price_naira_per_seat ⇒ Object
Returns the value of attribute price_naira_per_seat.
24 25 26 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 24 def price_naira_per_seat @price_naira_per_seat end |
#rate_cap_per_min ⇒ Object
Returns the value of attribute rate_cap_per_min.
26 27 28 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 26 def rate_cap_per_min @rate_cap_per_min end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 39 def self.attribute_map { :'name' => :'name', :'display_name' => :'display_name', :'description' => :'description', :'price_naira_per_seat' => :'price_naira_per_seat', :'rate_cap_per_min' => :'rate_cap_per_min', :'monthly_included_sends' => :'monthly_included_sends', :'has_shared_mailboxes' => :'has_shared_mailboxes', :'has_send_units' => :'has_send_units', :'has_ai_units' => :'has_ai_units', :'has_e2e_encryption' => :'has_e2e_encryption' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 360 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 65 def self.openapi_types { :'name' => :'String', :'display_name' => :'String', :'description' => :'String', :'price_naira_per_seat' => :'Integer', :'rate_cap_per_min' => :'Integer', :'monthly_included_sends' => :'Integer', :'has_shared_mailboxes' => :'Boolean', :'has_send_units' => :'Boolean', :'has_ai_units' => :'Boolean', :'has_e2e_encryption' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 330 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && display_name == o.display_name && description == o.description && price_naira_per_seat == o.price_naira_per_seat && rate_cap_per_min == o.rate_cap_per_min && monthly_included_sends == o.monthly_included_sends && has_shared_mailboxes == o.has_shared_mailboxes && has_send_units == o.has_send_units && has_ai_units == o.has_ai_units && has_e2e_encryption == o.has_e2e_encryption end |
#eql?(o) ⇒ Boolean
347 348 349 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 347 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
353 354 355 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 353 def hash [name, display_name, description, price_naira_per_seat, rate_cap_per_min, monthly_included_sends, has_shared_mailboxes, has_send_units, has_ai_units, has_e2e_encryption].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @display_name.nil? invalid_properties.push('invalid value for "display_name", display_name cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @price_naira_per_seat.nil? invalid_properties.push('invalid value for "price_naira_per_seat", price_naira_per_seat cannot be nil.') end if @rate_cap_per_min.nil? invalid_properties.push('invalid value for "rate_cap_per_min", rate_cap_per_min cannot be nil.') end if @monthly_included_sends.nil? invalid_properties.push('invalid value for "monthly_included_sends", monthly_included_sends cannot be nil.') end if @has_shared_mailboxes.nil? invalid_properties.push('invalid value for "has_shared_mailboxes", has_shared_mailboxes cannot be nil.') end if @has_send_units.nil? invalid_properties.push('invalid value for "has_send_units", has_send_units cannot be nil.') end if @has_ai_units.nil? invalid_properties.push('invalid value for "has_ai_units", has_ai_units cannot be nil.') end if @has_e2e_encryption.nil? invalid_properties.push('invalid value for "has_e2e_encryption", has_e2e_encryption cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 382 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/lockally/models/plan_catalog_entry.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @display_name.nil? return false if @description.nil? return false if @price_naira_per_seat.nil? return false if @rate_cap_per_min.nil? return false if @monthly_included_sends.nil? return false if @has_shared_mailboxes.nil? return false if @has_send_units.nil? return false if @has_ai_units.nil? return false if @has_e2e_encryption.nil? true end |