Class: Lockally::UpdateDirectoryPermissionsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/lockally/models/update_directory_permissions_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDirectoryPermissionsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::UpdateDirectoryPermissionsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::UpdateDirectoryPermissionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'contact_view_access')
    self.contact_view_access = attributes[:'contact_view_access']
  end

  if attributes.key?(:'contact_edit_access')
    self.contact_edit_access = attributes[:'contact_edit_access']
  end

  if attributes.key?(:'list_manage_access')
    self.list_manage_access = attributes[:'list_manage_access']
  end

  if attributes.key?(:'external_sharing')
    self.external_sharing = attributes[:'external_sharing']
  end
end

Instance Attribute Details

#contact_edit_accessObject

Returns the value of attribute contact_edit_access.



20
21
22
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 20

def contact_edit_access
  @contact_edit_access
end

#contact_view_accessObject

Returns the value of attribute contact_view_access.



18
19
20
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 18

def contact_view_access
  @contact_view_access
end

#external_sharingObject

Returns the value of attribute external_sharing.



24
25
26
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 24

def external_sharing
  @external_sharing
end

#list_manage_accessObject

Returns the value of attribute list_manage_access.



22
23
24
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 22

def list_manage_access
  @list_manage_access
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 49

def self.attribute_map
  {
    :'contact_view_access' => :'contact_view_access',
    :'contact_edit_access' => :'contact_edit_access',
    :'list_manage_access' => :'list_manage_access',
    :'external_sharing' => :'external_sharing'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 69

def self.openapi_types
  {
    :'contact_view_access' => :'String',
    :'contact_edit_access' => :'String',
    :'list_manage_access' => :'String',
    :'external_sharing' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      contact_view_access == o.contact_view_access &&
      contact_edit_access == o.contact_edit_access &&
      list_manage_access == o.list_manage_access &&
      external_sharing == o.external_sharing
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 199

def hash
  [contact_view_access, contact_edit_access, list_manage_access, external_sharing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/lockally/models/update_directory_permissions_request.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  contact_view_access_validator = EnumAttributeValidator.new('String', ["all_users", "same_department", "admins_only"])
  return false unless contact_view_access_validator.valid?(@contact_view_access)
  contact_edit_access_validator = EnumAttributeValidator.new('String', ["all_users", "admins_only"])
  return false unless contact_edit_access_validator.valid?(@contact_edit_access)
  list_manage_access_validator = EnumAttributeValidator.new('String', ["all_users", "list_owners", "admins_only"])
  return false unless list_manage_access_validator.valid?(@list_manage_access)
  external_sharing_validator = EnumAttributeValidator.new('String', ["allowed", "restricted", "disabled"])
  return false unless external_sharing_validator.valid?(@external_sharing)
  true
end