Class: Lockally::User
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::User
- Defined in:
- lib/lockally/models/user.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#department ⇒ Object
Returns the value of attribute department.
-
#email ⇒ Object
Returns the value of attribute email.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#mailbox_count ⇒ Object
Returns the value of attribute mailbox_count.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#title ⇒ Object
Returns the value of attribute title.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/lockally/models/user.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::User` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] else self.first_name = nil end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] else self.last_name = nil end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'department') self.department = attributes[:'department'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'mailbox_count') self.mailbox_count = attributes[:'mailbox_count'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/lockally/models/user.rb', line 34 def created_at @created_at end |
#department ⇒ Object
Returns the value of attribute department.
30 31 32 |
# File 'lib/lockally/models/user.rb', line 30 def department @department end |
#email ⇒ Object
Returns the value of attribute email.
22 23 24 |
# File 'lib/lockally/models/user.rb', line 22 def email @email end |
#first_name ⇒ Object
Returns the value of attribute first_name.
24 25 26 |
# File 'lib/lockally/models/user.rb', line 24 def first_name @first_name end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/user.rb', line 18 def id @id end |
#last_name ⇒ Object
Returns the value of attribute last_name.
26 27 28 |
# File 'lib/lockally/models/user.rb', line 26 def last_name @last_name end |
#mailbox_count ⇒ Object
Returns the value of attribute mailbox_count.
38 39 40 |
# File 'lib/lockally/models/user.rb', line 38 def mailbox_count @mailbox_count end |
#status ⇒ Object
Returns the value of attribute status.
32 33 34 |
# File 'lib/lockally/models/user.rb', line 32 def status @status end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
20 21 22 |
# File 'lib/lockally/models/user.rb', line 20 def tenant_id @tenant_id end |
#title ⇒ Object
Returns the value of attribute title.
28 29 30 |
# File 'lib/lockally/models/user.rb', line 28 def title @title end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/lockally/models/user.rb', line 36 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/lockally/models/user.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/lockally/models/user.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lockally/models/user.rb', line 63 def self.attribute_map { :'id' => :'id', :'tenant_id' => :'tenant_id', :'email' => :'email', :'first_name' => :'first_name', :'last_name' => :'last_name', :'title' => :'title', :'department' => :'department', :'status' => :'status', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'mailbox_count' => :'mailbox_count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/lockally/models/user.rb', line 359 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/lockally/models/user.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/lockally/models/user.rb', line 90 def self.openapi_types { :'id' => :'String', :'tenant_id' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'title' => :'String', :'department' => :'String', :'status' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time', :'mailbox_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/lockally/models/user.rb', line 328 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && tenant_id == o.tenant_id && email == o.email && first_name == o.first_name && last_name == o.last_name && title == o.title && department == o.department && status == o.status && created_at == o.created_at && updated_at == o.updated_at && mailbox_count == o.mailbox_count end |
#eql?(o) ⇒ Boolean
346 347 348 |
# File 'lib/lockally/models/user.rb', line 346 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
352 353 354 |
# File 'lib/lockally/models/user.rb', line 352 def hash [id, tenant_id, email, first_name, last_name, title, department, status, created_at, updated_at, mailbox_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/lockally/models/user.rb', line 191 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @first_name.nil? invalid_properties.push('invalid value for "first_name", first_name cannot be nil.') end if @last_name.nil? invalid_properties.push('invalid value for "last_name", last_name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/lockally/models/user.rb', line 381 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/lockally/models/user.rb', line 231 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @tenant_id.nil? return false if @email.nil? return false if @first_name.nil? return false if @last_name.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "suspended", "deprovisioned"]) return false unless status_validator.valid?(@status) return false if @created_at.nil? return false if @updated_at.nil? true end |