Class: Lockally::V1ApiKeysPost201Response

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/v1_api_keys_post201_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1ApiKeysPost201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::V1ApiKeysPost201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::V1ApiKeysPost201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'prefix')
    self.prefix = attributes[:'prefix']
  else
    self.prefix = nil
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  else
    self.scopes = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'revoked_at')
    self.revoked_at = attributes[:'revoked_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  else
    self.secret = nil
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



33
34
35
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 33

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 18

def id
  @id
end

#labelObject

Returns the value of attribute label.



27
28
29
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 27

def label
  @label
end

#last_used_atObject

Returns the value of attribute last_used_at.



29
30
31
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 29

def last_used_at
  @last_used_at
end

#prefixObject

8-char public prefix; safe to store and display.



23
24
25
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 23

def prefix
  @prefix
end

#revoked_atObject

Returns the value of attribute revoked_at.



31
32
33
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 31

def revoked_at
  @revoked_at
end

#scopesObject

Returns the value of attribute scopes.



25
26
27
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 25

def scopes
  @scopes
end

#secretObject

The full lk_live_<prefix>_<secret> token. Shown ONCE.



36
37
38
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 36

def secret
  @secret
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 20

def tenant_id
  @tenant_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'tenant_id' => :'tenant_id',
    :'prefix' => :'prefix',
    :'scopes' => :'scopes',
    :'label' => :'label',
    :'last_used_at' => :'last_used_at',
    :'revoked_at' => :'revoked_at',
    :'created_at' => :'created_at',
    :'secret' => :'secret'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



85
86
87
88
89
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 85

def self.openapi_all_of
  [
  :'APIKey'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 64

def self.openapi_types
  {
    :'id' => :'String',
    :'tenant_id' => :'String',
    :'prefix' => :'String',
    :'scopes' => :'Array<String>',
    :'label' => :'String',
    :'last_used_at' => :'Time',
    :'revoked_at' => :'Time',
    :'created_at' => :'Time',
    :'secret' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      tenant_id == o.tenant_id &&
      prefix == o.prefix &&
      scopes == o.scopes &&
      label == o.label &&
      last_used_at == o.last_used_at &&
      revoked_at == o.revoked_at &&
      created_at == o.created_at &&
      secret == o.secret
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 304

def hash
  [id, tenant_id, prefix, scopes, label, last_used_at, revoked_at, created_at, secret].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @prefix.nil?
    invalid_properties.push('invalid value for "prefix", prefix cannot be nil.')
  end

  if @scopes.nil?
    invalid_properties.push('invalid value for "scopes", scopes cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @secret.nil?
    invalid_properties.push('invalid value for "secret", secret cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
201
202
203
204
205
206
207
208
# File 'lib/lockally/models/v1_api_keys_post201_response.rb', line 198

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @tenant_id.nil?
  return false if @prefix.nil?
  return false if @scopes.nil?
  return false if @label.nil?
  return false if @created_at.nil?
  return false if @secret.nil?
  true
end