Class: Lockally::Webhook

Inherits:
ApiModelBase show all
Defined in:
lib/lockally/models/webhook.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Webhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/lockally/models/webhook.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Webhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  else
    self.tenant_id = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  else
    self.events = nil
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  else
    self.paused = nil
  end

  if attributes.key?(:'paused_at')
    self.paused_at = attributes[:'paused_at']
  end

  if attributes.key?(:'last_success_at')
    self.last_success_at = attributes[:'last_success_at']
  end

  if attributes.key?(:'last_failure_at')
    self.last_failure_at = attributes[:'last_failure_at']
  end

  if attributes.key?(:'consecutive_failures')
    self.consecutive_failures = attributes[:'consecutive_failures']
  else
    self.consecutive_failures = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'signing_secret')
    self.signing_secret = attributes[:'signing_secret']
  end
end

Instance Attribute Details

#consecutive_failuresObject

Returns the value of attribute consecutive_failures.



34
35
36
# File 'lib/lockally/models/webhook.rb', line 34

def consecutive_failures
  @consecutive_failures
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/lockally/models/webhook.rb', line 36

def created_at
  @created_at
end

#eventsObject

Returns the value of attribute events.



24
25
26
# File 'lib/lockally/models/webhook.rb', line 24

def events
  @events
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/lockally/models/webhook.rb', line 18

def id
  @id
end

#last_failure_atObject

Returns the value of attribute last_failure_at.



32
33
34
# File 'lib/lockally/models/webhook.rb', line 32

def last_failure_at
  @last_failure_at
end

#last_success_atObject

Returns the value of attribute last_success_at.



30
31
32
# File 'lib/lockally/models/webhook.rb', line 30

def last_success_at
  @last_success_at
end

#pausedObject

Returns the value of attribute paused.



26
27
28
# File 'lib/lockally/models/webhook.rb', line 26

def paused
  @paused
end

#paused_atObject

Returns the value of attribute paused_at.



28
29
30
# File 'lib/lockally/models/webhook.rb', line 28

def paused_at
  @paused_at
end

#signing_secretObject

Hex-encoded HMAC-SHA256 key. Present ONLY on POST response.



39
40
41
# File 'lib/lockally/models/webhook.rb', line 39

def signing_secret
  @signing_secret
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/lockally/models/webhook.rb', line 20

def tenant_id
  @tenant_id
end

#urlObject

Returns the value of attribute url.



22
23
24
# File 'lib/lockally/models/webhook.rb', line 22

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/lockally/models/webhook.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/lockally/models/webhook.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/lockally/models/webhook.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'tenant_id' => :'tenant_id',
    :'url' => :'url',
    :'events' => :'events',
    :'paused' => :'paused',
    :'paused_at' => :'paused_at',
    :'last_success_at' => :'last_success_at',
    :'last_failure_at' => :'last_failure_at',
    :'consecutive_failures' => :'consecutive_failures',
    :'created_at' => :'created_at',
    :'signing_secret' => :'signing_secret'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/lockally/models/webhook.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/lockally/models/webhook.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/lockally/models/webhook.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'tenant_id' => :'String',
    :'url' => :'String',
    :'events' => :'Array<String>',
    :'paused' => :'Boolean',
    :'paused_at' => :'Time',
    :'last_success_at' => :'Time',
    :'last_failure_at' => :'Time',
    :'consecutive_failures' => :'Integer',
    :'created_at' => :'Time',
    :'signing_secret' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/lockally/models/webhook.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      tenant_id == o.tenant_id &&
      url == o.url &&
      events == o.events &&
      paused == o.paused &&
      paused_at == o.paused_at &&
      last_success_at == o.last_success_at &&
      last_failure_at == o.last_failure_at &&
      consecutive_failures == o.consecutive_failures &&
      created_at == o.created_at &&
      signing_secret == o.signing_secret
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/lockally/models/webhook.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/lockally/models/webhook.rb', line 314

def hash
  [id, tenant_id, url, events, paused, paused_at, last_success_at, last_failure_at, consecutive_failures, created_at, signing_secret].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/lockally/models/webhook.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @tenant_id.nil?
    invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @events.nil?
    invalid_properties.push('invalid value for "events", events cannot be nil.')
  end

  if @paused.nil?
    invalid_properties.push('invalid value for "paused", paused cannot be nil.')
  end

  if @consecutive_failures.nil?
    invalid_properties.push('invalid value for "consecutive_failures", consecutive_failures cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/lockally/models/webhook.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
216
# File 'lib/lockally/models/webhook.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @tenant_id.nil?
  return false if @url.nil?
  return false if @events.nil?
  return false if @paused.nil?
  return false if @consecutive_failures.nil?
  return false if @created_at.nil?
  true
end