Class: Lockally::AdminsApi
- Inherits:
-
Object
- Object
- Lockally::AdminsApi
- Defined in:
- lib/lockally/api/admins_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AdminsApi
constructor
A new instance of AdminsApi.
-
#v1_admins_get(opts = {}) ⇒ V1AdminsGet200Response
List tenant admins.
-
#v1_admins_get_with_http_info(opts = {}) ⇒ Array<(V1AdminsGet200Response, Integer, Hash)>
List tenant admins.
-
#v1_admins_id_delete(id, opts = {}) ⇒ nil
Delete an admin Hard-delete.
-
#v1_admins_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an admin Hard-delete.
-
#v1_admins_id_patch(id, v1_admins_id_patch_request, opts = {}) ⇒ AdminFull
Update an admin Supply at least one of
password,display_name,role,disabled. -
#v1_admins_id_patch_with_http_info(id, v1_admins_id_patch_request, opts = {}) ⇒ Array<(AdminFull, Integer, Hash)>
Update an admin Supply at least one of `password`, `display_name`, `role`, `disabled`.
-
#v1_admins_post(v1_admins_post_request, opts = {}) ⇒ AdminFull
Invite a new admin Creates a new tenant admin.
-
#v1_admins_post_with_http_info(v1_admins_post_request, opts = {}) ⇒ Array<(AdminFull, Integer, Hash)>
Invite a new admin Creates a new tenant admin.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lockally/api/admins_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_admins_get(opts = {}) ⇒ V1AdminsGet200Response
List tenant admins
25 26 27 28 |
# File 'lib/lockally/api/admins_api.rb', line 25 def v1_admins_get(opts = {}) data, _status_code, _headers = v1_admins_get_with_http_info(opts) data end |
#v1_admins_get_with_http_info(opts = {}) ⇒ Array<(V1AdminsGet200Response, Integer, Hash)>
List tenant admins
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/lockally/api/admins_api.rb', line 33 def v1_admins_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminsApi.v1_admins_get ...' end # resource path local_var_path = '/v1/admins' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1AdminsGet200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AdminsApi.v1_admins_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminsApi#v1_admins_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_admins_id_delete(id, opts = {}) ⇒ nil
Delete an admin Hard-delete. Cascade-drops the admin's sessions (immediate revocation). Same safety rails as PATCH disabled=true.
82 83 84 85 |
# File 'lib/lockally/api/admins_api.rb', line 82 def v1_admins_id_delete(id, opts = {}) v1_admins_id_delete_with_http_info(id, opts) nil end |
#v1_admins_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an admin Hard-delete. Cascade-drops the admin's sessions (immediate revocation). Same safety rails as PATCH disabled=true.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/lockally/api/admins_api.rb', line 92 def v1_admins_id_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminsApi.v1_admins_id_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminsApi.v1_admins_id_delete" end # resource path local_var_path = '/v1/admins/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AdminsApi.v1_admins_id_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminsApi#v1_admins_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_admins_id_patch(id, v1_admins_id_patch_request, opts = {}) ⇒ AdminFull
Update an admin
Supply at least one of password, display_name, role, disabled. Safety rails. A session bearer (adm_sess_*) cannot disable itself — use another admin or an API key (which bypasses the self-rail). Disabling the last active admin returns 409 to prevent orphaning the tenant from its console.
146 147 148 149 |
# File 'lib/lockally/api/admins_api.rb', line 146 def v1_admins_id_patch(id, v1_admins_id_patch_request, opts = {}) data, _status_code, _headers = v1_admins_id_patch_with_http_info(id, v1_admins_id_patch_request, opts) data end |
#v1_admins_id_patch_with_http_info(id, v1_admins_id_patch_request, opts = {}) ⇒ Array<(AdminFull, Integer, Hash)>
Update an admin Supply at least one of `password`, `display_name`, `role`, `disabled`. Safety rails. A session bearer (adm_sess_*) cannot disable itself — use another admin or an API key (which bypasses the self-rail). Disabling the last active admin returns 409 to prevent orphaning the tenant from its console.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/lockally/api/admins_api.rb', line 157 def v1_admins_id_patch_with_http_info(id, v1_admins_id_patch_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminsApi.v1_admins_id_patch ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminsApi.v1_admins_id_patch" end # verify the required parameter 'v1_admins_id_patch_request' is set if @api_client.config.client_side_validation && v1_admins_id_patch_request.nil? fail ArgumentError, "Missing the required parameter 'v1_admins_id_patch_request' when calling AdminsApi.v1_admins_id_patch" end # resource path local_var_path = '/v1/admins/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_admins_id_patch_request) # return_type return_type = opts[:debug_return_type] || 'AdminFull' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AdminsApi.v1_admins_id_patch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminsApi#v1_admins_id_patch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_admins_post(v1_admins_post_request, opts = {}) ⇒ AdminFull
Invite a new admin
Creates a new tenant admin. If password is omitted, lockally generates a 16-char password and returns it ONCE in the response. Email is case-insensitive and unique per tenant.
219 220 221 222 |
# File 'lib/lockally/api/admins_api.rb', line 219 def v1_admins_post(v1_admins_post_request, opts = {}) data, _status_code, _headers = v1_admins_post_with_http_info(v1_admins_post_request, opts) data end |
#v1_admins_post_with_http_info(v1_admins_post_request, opts = {}) ⇒ Array<(AdminFull, Integer, Hash)>
Invite a new admin Creates a new tenant admin. If `password` is omitted, lockally generates a 16-char password and returns it ONCE in the response. Email is case-insensitive and unique per tenant.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/lockally/api/admins_api.rb', line 229 def v1_admins_post_with_http_info(v1_admins_post_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminsApi.v1_admins_post ...' end # verify the required parameter 'v1_admins_post_request' is set if @api_client.config.client_side_validation && v1_admins_post_request.nil? fail ArgumentError, "Missing the required parameter 'v1_admins_post_request' when calling AdminsApi.v1_admins_post" end # resource path local_var_path = '/v1/admins' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_admins_post_request) # return_type return_type = opts[:debug_return_type] || 'AdminFull' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AdminsApi.v1_admins_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminsApi#v1_admins_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |