Class: Lockally::ApiKeysApi
- Inherits:
-
Object
- Object
- Lockally::ApiKeysApi
- Defined in:
- lib/lockally/api/api_keys_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ApiKeysApi
constructor
A new instance of ApiKeysApi.
-
#v1_api_keys_get(opts = {}) ⇒ V1ApiKeysGet200Response
List API keys Returns all API keys (active and revoked) belonging to the calling tenant.
-
#v1_api_keys_get_with_http_info(opts = {}) ⇒ Array<(V1ApiKeysGet200Response, Integer, Hash)>
List API keys Returns all API keys (active and revoked) belonging to the calling tenant.
-
#v1_api_keys_id_delete(id, opts = {}) ⇒ nil
Revoke an API key Soft-deletes (sets
revoked_at) on the named key. -
#v1_api_keys_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke an API key Soft-deletes (sets `revoked_at`) on the named key.
-
#v1_api_keys_post(v1_api_keys_post_request, opts = {}) ⇒ V1ApiKeysPost201Response
Create an API key Provisions a fresh API key for the calling tenant.
-
#v1_api_keys_post_with_http_info(v1_api_keys_post_request, opts = {}) ⇒ Array<(V1ApiKeysPost201Response, Integer, Hash)>
Create an API key Provisions a fresh API key for the calling tenant.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ApiKeysApi
Returns a new instance of ApiKeysApi.
19 20 21 |
# File 'lib/lockally/api/api_keys_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lockally/api/api_keys_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_api_keys_get(opts = {}) ⇒ V1ApiKeysGet200Response
List API keys
Returns all API keys (active and revoked) belonging to the calling tenant. The secret is never returned — only prefix + metadata.
26 27 28 29 |
# File 'lib/lockally/api/api_keys_api.rb', line 26 def v1_api_keys_get(opts = {}) data, _status_code, _headers = v1_api_keys_get_with_http_info(opts) data end |
#v1_api_keys_get_with_http_info(opts = {}) ⇒ Array<(V1ApiKeysGet200Response, Integer, Hash)>
List API keys Returns all API keys (active and revoked) belonging to the calling tenant. The `secret` is never returned — only prefix + metadata.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lockally/api/api_keys_api.rb', line 35 def v1_api_keys_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApiKeysApi.v1_api_keys_get ...' end # resource path local_var_path = '/v1/api-keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1ApiKeysGet200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ApiKeysApi.v1_api_keys_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApiKeysApi#v1_api_keys_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_api_keys_id_delete(id, opts = {}) ⇒ nil
Revoke an API key
Soft-deletes (sets revoked_at) on the named key. The row stays for audit purposes; the key no longer authenticates. You cannot revoke the key currently being used to make this call — that would lock you out. Use a different tenant:admin key.
84 85 86 87 |
# File 'lib/lockally/api/api_keys_api.rb', line 84 def v1_api_keys_id_delete(id, opts = {}) v1_api_keys_id_delete_with_http_info(id, opts) nil end |
#v1_api_keys_id_delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke an API key Soft-deletes (sets `revoked_at`) on the named key. The row stays for audit purposes; the key no longer authenticates. You cannot revoke the key currently being used to make this call — that would lock you out. Use a different `tenant:admin` key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/lockally/api/api_keys_api.rb', line 94 def v1_api_keys_id_delete_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApiKeysApi.v1_api_keys_id_delete ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ApiKeysApi.v1_api_keys_id_delete" end # resource path local_var_path = '/v1/api-keys/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ApiKeysApi.v1_api_keys_id_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApiKeysApi#v1_api_keys_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_api_keys_post(v1_api_keys_post_request, opts = {}) ⇒ V1ApiKeysPost201Response
Create an API key
Provisions a fresh API key for the calling tenant. The full secret is included in this response ONLY — store it immediately. The cleartext secret is not recoverable from the argon2id hash kept server-side; rotate by creating a new key and revoking the old one.
147 148 149 150 |
# File 'lib/lockally/api/api_keys_api.rb', line 147 def v1_api_keys_post(v1_api_keys_post_request, opts = {}) data, _status_code, _headers = v1_api_keys_post_with_http_info(v1_api_keys_post_request, opts) data end |
#v1_api_keys_post_with_http_info(v1_api_keys_post_request, opts = {}) ⇒ Array<(V1ApiKeysPost201Response, Integer, Hash)>
Create an API key Provisions a fresh API key for the calling tenant. The full `secret` is included in this response ONLY — store it immediately. The cleartext secret is not recoverable from the argon2id hash kept server-side; rotate by creating a new key and revoking the old one.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/lockally/api/api_keys_api.rb', line 157 def v1_api_keys_post_with_http_info(v1_api_keys_post_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApiKeysApi.v1_api_keys_post ...' end # verify the required parameter 'v1_api_keys_post_request' is set if @api_client.config.client_side_validation && v1_api_keys_post_request.nil? fail ArgumentError, "Missing the required parameter 'v1_api_keys_post_request' when calling ApiKeysApi.v1_api_keys_post" end # resource path local_var_path = '/v1/api-keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_api_keys_post_request) # return_type return_type = opts[:debug_return_type] || 'V1ApiKeysPost201Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ApiKeysApi.v1_api_keys_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApiKeysApi#v1_api_keys_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |