Class: Lockally::Calendar
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::Calendar
- Defined in:
- lib/lockally/models/calendar.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#color ⇒ Object
Returns the value of attribute color.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#event_count ⇒ Object
Returns the value of attribute event_count.
-
#feed_url ⇒ Object
Returns the value of attribute feed_url.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#owner_email ⇒ Object
Returns the value of attribute owner_email.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#visibility ⇒ Object
Returns the value of attribute visibility.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Calendar
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Calendar
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/lockally/models/calendar.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Calendar` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Calendar`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'owner_email') self.owner_email = attributes[:'owner_email'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'visibility') self.visibility = attributes[:'visibility'] else self.visibility = nil end if attributes.key?(:'feed_url') self.feed_url = attributes[:'feed_url'] end if attributes.key?(:'event_count') self.event_count = attributes[:'event_count'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#color ⇒ Object
Returns the value of attribute color.
24 25 26 |
# File 'lib/lockally/models/calendar.rb', line 24 def color @color end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/lockally/models/calendar.rb', line 36 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/lockally/models/calendar.rb', line 28 def description @description end |
#event_count ⇒ Object
Returns the value of attribute event_count.
34 35 36 |
# File 'lib/lockally/models/calendar.rb', line 34 def event_count @event_count end |
#feed_url ⇒ Object
Returns the value of attribute feed_url.
32 33 34 |
# File 'lib/lockally/models/calendar.rb', line 32 def feed_url @feed_url end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/calendar.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/lockally/models/calendar.rb', line 22 def name @name end |
#owner_email ⇒ Object
Returns the value of attribute owner_email.
26 27 28 |
# File 'lib/lockally/models/calendar.rb', line 26 def owner_email @owner_email end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
20 21 22 |
# File 'lib/lockally/models/calendar.rb', line 20 def tenant_id @tenant_id end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
38 39 40 |
# File 'lib/lockally/models/calendar.rb', line 38 def updated_at @updated_at end |
#visibility ⇒ Object
Returns the value of attribute visibility.
30 31 32 |
# File 'lib/lockally/models/calendar.rb', line 30 def visibility @visibility end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/lockally/models/calendar.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/lockally/models/calendar.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lockally/models/calendar.rb', line 63 def self.attribute_map { :'id' => :'id', :'tenant_id' => :'tenant_id', :'name' => :'name', :'color' => :'color', :'owner_email' => :'owner_email', :'description' => :'description', :'visibility' => :'visibility', :'feed_url' => :'feed_url', :'event_count' => :'event_count', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/lockally/models/calendar.rb', line 325 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/lockally/models/calendar.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/lockally/models/calendar.rb', line 90 def self.openapi_types { :'id' => :'String', :'tenant_id' => :'String', :'name' => :'String', :'color' => :'String', :'owner_email' => :'String', :'description' => :'String', :'visibility' => :'String', :'feed_url' => :'String', :'event_count' => :'Integer', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/lockally/models/calendar.rb', line 294 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && tenant_id == o.tenant_id && name == o.name && color == o.color && owner_email == o.owner_email && description == o.description && visibility == o.visibility && feed_url == o.feed_url && event_count == o.event_count && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
312 313 314 |
# File 'lib/lockally/models/calendar.rb', line 312 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
318 319 320 |
# File 'lib/lockally/models/calendar.rb', line 318 def hash [id, tenant_id, name, color, owner_email, description, visibility, feed_url, event_count, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/lockally/models/calendar.rb', line 187 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @visibility.nil? invalid_properties.push('invalid value for "visibility", visibility cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/lockally/models/calendar.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/lockally/models/calendar.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @tenant_id.nil? return false if @name.nil? return false if @visibility.nil? visibility_validator = EnumAttributeValidator.new('String', ["private", "tenant"]) return false unless visibility_validator.valid?(@visibility) return false if @created_at.nil? return false if @updated_at.nil? true end |