Class: Lockally::DirectoryPermissions
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::DirectoryPermissions
- Defined in:
- lib/lockally/models/directory_permissions.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#contact_edit_access ⇒ Object
Returns the value of attribute contact_edit_access.
-
#contact_view_access ⇒ Object
Returns the value of attribute contact_view_access.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#external_sharing ⇒ Object
Returns the value of attribute external_sharing.
-
#list_manage_access ⇒ Object
Returns the value of attribute list_manage_access.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DirectoryPermissions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DirectoryPermissions
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/lockally/models/directory_permissions.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::DirectoryPermissions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::DirectoryPermissions`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'contact_view_access') self.contact_view_access = attributes[:'contact_view_access'] else self.contact_view_access = nil end if attributes.key?(:'contact_edit_access') self.contact_edit_access = attributes[:'contact_edit_access'] else self.contact_edit_access = nil end if attributes.key?(:'list_manage_access') self.list_manage_access = attributes[:'list_manage_access'] else self.list_manage_access = nil end if attributes.key?(:'external_sharing') self.external_sharing = attributes[:'external_sharing'] else self.external_sharing = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#contact_edit_access ⇒ Object
Returns the value of attribute contact_edit_access.
22 23 24 |
# File 'lib/lockally/models/directory_permissions.rb', line 22 def contact_edit_access @contact_edit_access end |
#contact_view_access ⇒ Object
Returns the value of attribute contact_view_access.
20 21 22 |
# File 'lib/lockally/models/directory_permissions.rb', line 20 def contact_view_access @contact_view_access end |
#created_at ⇒ Object
Returns the value of attribute created_at.
28 29 30 |
# File 'lib/lockally/models/directory_permissions.rb', line 28 def created_at @created_at end |
#external_sharing ⇒ Object
Returns the value of attribute external_sharing.
26 27 28 |
# File 'lib/lockally/models/directory_permissions.rb', line 26 def external_sharing @external_sharing end |
#list_manage_access ⇒ Object
Returns the value of attribute list_manage_access.
24 25 26 |
# File 'lib/lockally/models/directory_permissions.rb', line 24 def list_manage_access @list_manage_access end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
18 19 20 |
# File 'lib/lockally/models/directory_permissions.rb', line 18 def tenant_id @tenant_id end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
30 31 32 |
# File 'lib/lockally/models/directory_permissions.rb', line 30 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/lockally/models/directory_permissions.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/lockally/models/directory_permissions.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/lockally/models/directory_permissions.rb', line 55 def self.attribute_map { :'tenant_id' => :'tenant_id', :'contact_view_access' => :'contact_view_access', :'contact_edit_access' => :'contact_edit_access', :'list_manage_access' => :'list_manage_access', :'external_sharing' => :'external_sharing', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/lockally/models/directory_permissions.rb', line 278 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/lockally/models/directory_permissions.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lockally/models/directory_permissions.rb', line 78 def self.openapi_types { :'tenant_id' => :'String', :'contact_view_access' => :'String', :'contact_edit_access' => :'String', :'list_manage_access' => :'String', :'external_sharing' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/lockally/models/directory_permissions.rb', line 251 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && contact_view_access == o.contact_view_access && contact_edit_access == o.contact_edit_access && list_manage_access == o.list_manage_access && external_sharing == o.external_sharing && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/lockally/models/directory_permissions.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/lockally/models/directory_permissions.rb', line 271 def hash [tenant_id, contact_view_access, contact_edit_access, list_manage_access, external_sharing, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/lockally/models/directory_permissions.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @contact_view_access.nil? invalid_properties.push('invalid value for "contact_view_access", contact_view_access cannot be nil.') end if @contact_edit_access.nil? invalid_properties.push('invalid value for "contact_edit_access", contact_edit_access cannot be nil.') end if @list_manage_access.nil? invalid_properties.push('invalid value for "list_manage_access", list_manage_access cannot be nil.') end if @external_sharing.nil? invalid_properties.push('invalid value for "external_sharing", external_sharing cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/lockally/models/directory_permissions.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/lockally/models/directory_permissions.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tenant_id.nil? return false if @contact_view_access.nil? contact_view_access_validator = EnumAttributeValidator.new('String', ["all_users", "same_department", "admins_only"]) return false unless contact_view_access_validator.valid?(@contact_view_access) return false if @contact_edit_access.nil? contact_edit_access_validator = EnumAttributeValidator.new('String', ["all_users", "admins_only"]) return false unless contact_edit_access_validator.valid?(@contact_edit_access) return false if @list_manage_access.nil? list_manage_access_validator = EnumAttributeValidator.new('String', ["all_users", "list_owners", "admins_only"]) return false unless list_manage_access_validator.valid?(@list_manage_access) return false if @external_sharing.nil? external_sharing_validator = EnumAttributeValidator.new('String', ["allowed", "restricted", "disabled"]) return false unless external_sharing_validator.valid?(@external_sharing) true end |