Class: Lockally::DomainsApi
- Inherits:
-
Object
- Object
- Lockally::DomainsApi
- Defined in:
- lib/lockally/api/domains_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
constructor
A new instance of DomainsApi.
-
#v1_domains_domain_delete(domain, opts = {}) ⇒ nil
Delete a domain Removes the domain registration.
-
#v1_domains_domain_delete_with_http_info(domain, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a domain Removes the domain registration.
-
#v1_domains_domain_get(domain, opts = {}) ⇒ Domain
Get a domain.
-
#v1_domains_domain_get_with_http_info(domain, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Get a domain.
-
#v1_domains_domain_verify_post(domain, opts = {}) ⇒ Domain
Force-poll DNS verification Synchronously checks the
_lockally-verify.<domain>TXT record against the stored verification token. -
#v1_domains_domain_verify_post_with_http_info(domain, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Force-poll DNS verification Synchronously checks the `_lockally-verify.<domain>` TXT record against the stored verification token.
-
#v1_domains_get(opts = {}) ⇒ V1DomainsGet200Response
List domains Returns every domain registered under the calling tenant.
-
#v1_domains_get_with_http_info(opts = {}) ⇒ Array<(V1DomainsGet200Response, Integer, Hash)>
List domains Returns every domain registered under the calling tenant.
-
#v1_domains_post(v1_domains_post_request, opts = {}) ⇒ Domain
Register a domain Registers a new domain for the calling tenant.
-
#v1_domains_post_with_http_info(v1_domains_post_request, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Register a domain Registers a new domain for the calling tenant.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DomainsApi
Returns a new instance of DomainsApi.
19 20 21 |
# File 'lib/lockally/api/domains_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lockally/api/domains_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_domains_domain_delete(domain, opts = {}) ⇒ nil
Delete a domain Removes the domain registration. Refuses with 409 if any mailbox is still attached — delete the mailboxes first.
27 28 29 30 |
# File 'lib/lockally/api/domains_api.rb', line 27 def v1_domains_domain_delete(domain, opts = {}) v1_domains_domain_delete_with_http_info(domain, opts) nil end |
#v1_domains_domain_delete_with_http_info(domain, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a domain Removes the domain registration. Refuses with 409 if any mailbox is still attached — delete the mailboxes first.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/lockally/api/domains_api.rb', line 37 def v1_domains_domain_delete_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.v1_domains_domain_delete ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling DomainsApi.v1_domains_domain_delete" end # resource path local_var_path = '/v1/domains/{domain}'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainsApi.v1_domains_domain_delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#v1_domains_domain_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_domains_domain_get(domain, opts = {}) ⇒ Domain
Get a domain
89 90 91 92 |
# File 'lib/lockally/api/domains_api.rb', line 89 def v1_domains_domain_get(domain, opts = {}) data, _status_code, _headers = v1_domains_domain_get_with_http_info(domain, opts) data end |
#v1_domains_domain_get_with_http_info(domain, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Get a domain
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/lockally/api/domains_api.rb', line 98 def v1_domains_domain_get_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.v1_domains_domain_get ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling DomainsApi.v1_domains_domain_get" end # resource path local_var_path = '/v1/domains/{domain}'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Domain' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainsApi.v1_domains_domain_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#v1_domains_domain_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_domains_domain_verify_post(domain, opts = {}) ⇒ Domain
Force-poll DNS verification
Synchronously checks the _lockally-verify.<domain> TXT record against the stored verification token. Returns 200 either way: the returned verified boolean tells you whether DNS now confirms. Caller polls until verified: true. In v2 a background worker auto-polls and fires a domain.verified webhook.
151 152 153 154 |
# File 'lib/lockally/api/domains_api.rb', line 151 def v1_domains_domain_verify_post(domain, opts = {}) data, _status_code, _headers = v1_domains_domain_verify_post_with_http_info(domain, opts) data end |
#v1_domains_domain_verify_post_with_http_info(domain, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Force-poll DNS verification Synchronously checks the `_lockally-verify.<domain>` TXT record against the stored verification token. Returns 200 either way: the returned `verified` boolean tells you whether DNS now confirms. Caller polls until `verified: true`. In v2 a background worker auto-polls and fires a `domain.verified` webhook.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/lockally/api/domains_api.rb', line 161 def v1_domains_domain_verify_post_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.v1_domains_domain_verify_post ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling DomainsApi.v1_domains_domain_verify_post" end # resource path local_var_path = '/v1/domains/{domain}/verify'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Domain' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainsApi.v1_domains_domain_verify_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#v1_domains_domain_verify_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_domains_get(opts = {}) ⇒ V1DomainsGet200Response
List domains Returns every domain registered under the calling tenant.
213 214 215 216 |
# File 'lib/lockally/api/domains_api.rb', line 213 def v1_domains_get(opts = {}) data, _status_code, _headers = v1_domains_get_with_http_info(opts) data end |
#v1_domains_get_with_http_info(opts = {}) ⇒ Array<(V1DomainsGet200Response, Integer, Hash)>
List domains Returns every domain registered under the calling tenant.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/lockally/api/domains_api.rb', line 222 def v1_domains_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.v1_domains_get ...' end # resource path local_var_path = '/v1/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1DomainsGet200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainsApi.v1_domains_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#v1_domains_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_domains_post(v1_domains_post_request, opts = {}) ⇒ Domain
Register a domain
Registers a new domain for the calling tenant. Generates a DKIM keypair and verification token. Returns DNS instructions the tenant must publish under their own DNS (verification TXT, SPF include, DKIM TXT, MX records to mx1/mx2.lockally.com, DMARC seed). Idempotent — re-posting the same domain returns the existing record with the same DKIM keys and token (regenerating would break the tenant's published DNS). Returns 200 on idempotent hit, 201 on first create. Returns 409 if the domain is already claimed by a different tenant.
271 272 273 274 |
# File 'lib/lockally/api/domains_api.rb', line 271 def v1_domains_post(v1_domains_post_request, opts = {}) data, _status_code, _headers = v1_domains_post_with_http_info(v1_domains_post_request, opts) data end |
#v1_domains_post_with_http_info(v1_domains_post_request, opts = {}) ⇒ Array<(Domain, Integer, Hash)>
Register a domain Registers a new domain for the calling tenant. Generates a DKIM keypair and verification token. Returns DNS instructions the tenant must publish under their own DNS (verification TXT, SPF include, DKIM TXT, MX records to `mx1`/`mx2.lockally.com`, DMARC seed). Idempotent — re-posting the same domain returns the existing record with the same DKIM keys and token (regenerating would break the tenant's published DNS). Returns 200 on idempotent hit, 201 on first create. Returns 409 if the domain is already claimed by a different tenant.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/lockally/api/domains_api.rb', line 281 def v1_domains_post_with_http_info(v1_domains_post_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainsApi.v1_domains_post ...' end # verify the required parameter 'v1_domains_post_request' is set if @api_client.config.client_side_validation && v1_domains_post_request.nil? fail ArgumentError, "Missing the required parameter 'v1_domains_post_request' when calling DomainsApi.v1_domains_post" end # resource path local_var_path = '/v1/domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(v1_domains_post_request) # return_type return_type = opts[:debug_return_type] || 'Domain' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainsApi.v1_domains_post", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainsApi#v1_domains_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |