Class: Lockally::MigrationEvent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::MigrationEvent
- Defined in:
- lib/lockally/models/migration_event.rb
Instance Attribute Summary collapse
-
#actor ⇒ Object
Returns the value of attribute actor.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#detail ⇒ Object
Returns the value of attribute detail.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#id ⇒ Object
Returns the value of attribute id.
-
#mailbox_id ⇒ Object
Returns the value of attribute mailbox_id.
-
#migration_id ⇒ Object
Returns the value of attribute migration_id.
-
#new_status ⇒ Object
Returns the value of attribute new_status.
-
#old_status ⇒ Object
Returns the value of attribute old_status.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MigrationEvent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MigrationEvent
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/lockally/models/migration_event.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::MigrationEvent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::MigrationEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'migration_id') self.migration_id = attributes[:'migration_id'] else self.migration_id = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'mailbox_id') self.mailbox_id = attributes[:'mailbox_id'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] else self.event_type = nil end if attributes.key?(:'actor') self.actor = attributes[:'actor'] else self.actor = nil end if attributes.key?(:'old_status') self.old_status = attributes[:'old_status'] end if attributes.key?(:'new_status') self.new_status = attributes[:'new_status'] end if attributes.key?(:'detail') self.detail = attributes[:'detail'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#actor ⇒ Object
Returns the value of attribute actor.
28 29 30 |
# File 'lib/lockally/models/migration_event.rb', line 28 def actor @actor end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/lockally/models/migration_event.rb', line 36 def created_at @created_at end |
#detail ⇒ Object
Returns the value of attribute detail.
34 35 36 |
# File 'lib/lockally/models/migration_event.rb', line 34 def detail @detail end |
#event_type ⇒ Object
Returns the value of attribute event_type.
26 27 28 |
# File 'lib/lockally/models/migration_event.rb', line 26 def event_type @event_type end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/migration_event.rb', line 18 def id @id end |
#mailbox_id ⇒ Object
Returns the value of attribute mailbox_id.
24 25 26 |
# File 'lib/lockally/models/migration_event.rb', line 24 def mailbox_id @mailbox_id end |
#migration_id ⇒ Object
Returns the value of attribute migration_id.
20 21 22 |
# File 'lib/lockally/models/migration_event.rb', line 20 def migration_id @migration_id end |
#new_status ⇒ Object
Returns the value of attribute new_status.
32 33 34 |
# File 'lib/lockally/models/migration_event.rb', line 32 def new_status @new_status end |
#old_status ⇒ Object
Returns the value of attribute old_status.
30 31 32 |
# File 'lib/lockally/models/migration_event.rb', line 30 def old_status @old_status end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
22 23 24 |
# File 'lib/lockally/models/migration_event.rb', line 22 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/lockally/models/migration_event.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/lockally/models/migration_event.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/lockally/models/migration_event.rb', line 39 def self.attribute_map { :'id' => :'id', :'migration_id' => :'migration_id', :'tenant_id' => :'tenant_id', :'mailbox_id' => :'mailbox_id', :'event_type' => :'event_type', :'actor' => :'actor', :'old_status' => :'old_status', :'new_status' => :'new_status', :'detail' => :'detail', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/lockally/models/migration_event.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/lockally/models/migration_event.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/lockally/models/migration_event.rb', line 65 def self.openapi_types { :'id' => :'String', :'migration_id' => :'String', :'tenant_id' => :'String', :'mailbox_id' => :'String', :'event_type' => :'String', :'actor' => :'String', :'old_status' => :'String', :'new_status' => :'String', :'detail' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/lockally/models/migration_event.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && migration_id == o.migration_id && tenant_id == o.tenant_id && mailbox_id == o.mailbox_id && event_type == o.event_type && actor == o.actor && old_status == o.old_status && new_status == o.new_status && detail == o.detail && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/lockally/models/migration_event.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/lockally/models/migration_event.rb', line 285 def hash [id, migration_id, tenant_id, mailbox_id, event_type, actor, old_status, new_status, detail, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/lockally/models/migration_event.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @migration_id.nil? invalid_properties.push('invalid value for "migration_id", migration_id cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end if @actor.nil? invalid_properties.push('invalid value for "actor", actor cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/lockally/models/migration_event.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 |
# File 'lib/lockally/models/migration_event.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @migration_id.nil? return false if @tenant_id.nil? return false if @event_type.nil? return false if @actor.nil? return false if @created_at.nil? true end |