Class: Lockally::MigrationProgress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::MigrationProgress
- Defined in:
- lib/lockally/models/migration_progress.rb
Instance Attribute Summary collapse
-
#completed_mailboxes ⇒ Object
Returns the value of attribute completed_mailboxes.
-
#failed_mailboxes ⇒ Object
Returns the value of attribute failed_mailboxes.
-
#failed_messages ⇒ Object
Returns the value of attribute failed_messages.
-
#mailboxes ⇒ Object
Returns the value of attribute mailboxes.
-
#migration_id ⇒ Object
Returns the value of attribute migration_id.
-
#percent_complete ⇒ Object
Returns the value of attribute percent_complete.
-
#status ⇒ Object
Returns the value of attribute status.
-
#synced_messages ⇒ Object
Returns the value of attribute synced_messages.
-
#total_mailboxes ⇒ Object
Returns the value of attribute total_mailboxes.
-
#total_messages ⇒ Object
Returns the value of attribute total_messages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MigrationProgress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MigrationProgress
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/lockally/models/migration_progress.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::MigrationProgress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::MigrationProgress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'migration_id') self.migration_id = attributes[:'migration_id'] else self.migration_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'total_mailboxes') self.total_mailboxes = attributes[:'total_mailboxes'] else self.total_mailboxes = nil end if attributes.key?(:'completed_mailboxes') self.completed_mailboxes = attributes[:'completed_mailboxes'] else self.completed_mailboxes = nil end if attributes.key?(:'failed_mailboxes') self.failed_mailboxes = attributes[:'failed_mailboxes'] else self.failed_mailboxes = nil end if attributes.key?(:'total_messages') self. = attributes[:'total_messages'] else self. = nil end if attributes.key?(:'synced_messages') self. = attributes[:'synced_messages'] else self. = nil end if attributes.key?(:'failed_messages') self. = attributes[:'failed_messages'] else self. = nil end if attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] else self.percent_complete = nil end if attributes.key?(:'mailboxes') if (value = attributes[:'mailboxes']).is_a?(Array) self.mailboxes = value end else self.mailboxes = nil end end |
Instance Attribute Details
#completed_mailboxes ⇒ Object
Returns the value of attribute completed_mailboxes.
24 25 26 |
# File 'lib/lockally/models/migration_progress.rb', line 24 def completed_mailboxes @completed_mailboxes end |
#failed_mailboxes ⇒ Object
Returns the value of attribute failed_mailboxes.
26 27 28 |
# File 'lib/lockally/models/migration_progress.rb', line 26 def failed_mailboxes @failed_mailboxes end |
#failed_messages ⇒ Object
Returns the value of attribute failed_messages.
32 33 34 |
# File 'lib/lockally/models/migration_progress.rb', line 32 def @failed_messages end |
#mailboxes ⇒ Object
Returns the value of attribute mailboxes.
36 37 38 |
# File 'lib/lockally/models/migration_progress.rb', line 36 def mailboxes @mailboxes end |
#migration_id ⇒ Object
Returns the value of attribute migration_id.
18 19 20 |
# File 'lib/lockally/models/migration_progress.rb', line 18 def migration_id @migration_id end |
#percent_complete ⇒ Object
Returns the value of attribute percent_complete.
34 35 36 |
# File 'lib/lockally/models/migration_progress.rb', line 34 def percent_complete @percent_complete end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/lockally/models/migration_progress.rb', line 20 def status @status end |
#synced_messages ⇒ Object
Returns the value of attribute synced_messages.
30 31 32 |
# File 'lib/lockally/models/migration_progress.rb', line 30 def @synced_messages end |
#total_mailboxes ⇒ Object
Returns the value of attribute total_mailboxes.
22 23 24 |
# File 'lib/lockally/models/migration_progress.rb', line 22 def total_mailboxes @total_mailboxes end |
#total_messages ⇒ Object
Returns the value of attribute total_messages.
28 29 30 |
# File 'lib/lockally/models/migration_progress.rb', line 28 def @total_messages end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/lockally/models/migration_progress.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/lockally/models/migration_progress.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/lockally/models/migration_progress.rb', line 39 def self.attribute_map { :'migration_id' => :'migration_id', :'status' => :'status', :'total_mailboxes' => :'total_mailboxes', :'completed_mailboxes' => :'completed_mailboxes', :'failed_mailboxes' => :'failed_mailboxes', :'total_messages' => :'total_messages', :'synced_messages' => :'synced_messages', :'failed_messages' => :'failed_messages', :'percent_complete' => :'percent_complete', :'mailboxes' => :'mailboxes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/lockally/models/migration_progress.rb', line 362 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/lockally/models/migration_progress.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/lockally/models/migration_progress.rb', line 65 def self.openapi_types { :'migration_id' => :'String', :'status' => :'String', :'total_mailboxes' => :'Integer', :'completed_mailboxes' => :'Integer', :'failed_mailboxes' => :'Integer', :'total_messages' => :'Integer', :'synced_messages' => :'Integer', :'failed_messages' => :'Integer', :'percent_complete' => :'Float', :'mailboxes' => :'Array<MigrationProgressMailboxesInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/lockally/models/migration_progress.rb', line 332 def ==(o) return true if self.equal?(o) self.class == o.class && migration_id == o.migration_id && status == o.status && total_mailboxes == o.total_mailboxes && completed_mailboxes == o.completed_mailboxes && failed_mailboxes == o.failed_mailboxes && == o. && == o. && == o. && percent_complete == o.percent_complete && mailboxes == o.mailboxes end |
#eql?(o) ⇒ Boolean
349 350 351 |
# File 'lib/lockally/models/migration_progress.rb', line 349 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
355 356 357 |
# File 'lib/lockally/models/migration_progress.rb', line 355 def hash [migration_id, status, total_mailboxes, completed_mailboxes, failed_mailboxes, , , , percent_complete, mailboxes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/lockally/models/migration_progress.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @migration_id.nil? invalid_properties.push('invalid value for "migration_id", migration_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @total_mailboxes.nil? invalid_properties.push('invalid value for "total_mailboxes", total_mailboxes cannot be nil.') end if @completed_mailboxes.nil? invalid_properties.push('invalid value for "completed_mailboxes", completed_mailboxes cannot be nil.') end if @failed_mailboxes.nil? invalid_properties.push('invalid value for "failed_mailboxes", failed_mailboxes cannot be nil.') end if @total_messages.nil? invalid_properties.push('invalid value for "total_messages", total_messages cannot be nil.') end if @synced_messages.nil? invalid_properties.push('invalid value for "synced_messages", synced_messages cannot be nil.') end if @failed_messages.nil? invalid_properties.push('invalid value for "failed_messages", failed_messages cannot be nil.') end if @percent_complete.nil? invalid_properties.push('invalid value for "percent_complete", percent_complete cannot be nil.') end if @mailboxes.nil? invalid_properties.push('invalid value for "mailboxes", mailboxes cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/lockally/models/migration_progress.rb', line 384 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/lockally/models/migration_progress.rb', line 215 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @migration_id.nil? return false if @status.nil? return false if @total_mailboxes.nil? return false if @completed_mailboxes.nil? return false if @failed_mailboxes.nil? return false if @total_messages.nil? return false if @synced_messages.nil? return false if @failed_messages.nil? return false if @percent_complete.nil? return false if @mailboxes.nil? true end |