Class: Lockally::Tenant
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Lockally::Tenant
- Defined in:
- lib/lockally/models/tenant.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_email ⇒ Object
Returns the value of attribute admin_email.
-
#closed_at ⇒ Object
Returns the value of attribute closed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#daily_msg_quota ⇒ Object
Returns the value of attribute daily_msg_quota.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#hard_delete_after ⇒ Object
Returns the value of attribute hard_delete_after.
-
#id ⇒ Object
Returns the value of attribute id.
-
#plan ⇒ Object
Returns the value of attribute plan.
-
#rate_cap_per_min ⇒ Object
Per-tenant share of the per-VPS 5/min outbound cap (L6).
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#status ⇒ Object
Returns the value of attribute status.
-
#suspended_at ⇒ Object
Returns the value of attribute suspended_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Tenant
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Tenant
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/lockally/models/tenant.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Lockally::Tenant` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Lockally::Tenant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] else self.display_name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'plan') self.plan = attributes[:'plan'] else self.plan = nil end if attributes.key?(:'rate_cap_per_min') self.rate_cap_per_min = attributes[:'rate_cap_per_min'] else self.rate_cap_per_min = nil end if attributes.key?(:'daily_msg_quota') self.daily_msg_quota = attributes[:'daily_msg_quota'] else self.daily_msg_quota = nil end if attributes.key?(:'admin_email') self.admin_email = attributes[:'admin_email'] else self.admin_email = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'suspended_at') self.suspended_at = attributes[:'suspended_at'] end if attributes.key?(:'closed_at') self.closed_at = attributes[:'closed_at'] end if attributes.key?(:'hard_delete_after') self.hard_delete_after = attributes[:'hard_delete_after'] end end |
Instance Attribute Details
#admin_email ⇒ Object
Returns the value of attribute admin_email.
33 34 35 |
# File 'lib/lockally/models/tenant.rb', line 33 def admin_email @admin_email end |
#closed_at ⇒ Object
Returns the value of attribute closed_at.
39 40 41 |
# File 'lib/lockally/models/tenant.rb', line 39 def closed_at @closed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
35 36 37 |
# File 'lib/lockally/models/tenant.rb', line 35 def created_at @created_at end |
#daily_msg_quota ⇒ Object
Returns the value of attribute daily_msg_quota.
31 32 33 |
# File 'lib/lockally/models/tenant.rb', line 31 def daily_msg_quota @daily_msg_quota end |
#display_name ⇒ Object
Returns the value of attribute display_name.
22 23 24 |
# File 'lib/lockally/models/tenant.rb', line 22 def display_name @display_name end |
#hard_delete_after ⇒ Object
Returns the value of attribute hard_delete_after.
41 42 43 |
# File 'lib/lockally/models/tenant.rb', line 41 def hard_delete_after @hard_delete_after end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/lockally/models/tenant.rb', line 18 def id @id end |
#plan ⇒ Object
Returns the value of attribute plan.
26 27 28 |
# File 'lib/lockally/models/tenant.rb', line 26 def plan @plan end |
#rate_cap_per_min ⇒ Object
Per-tenant share of the per-VPS 5/min outbound cap (L6).
29 30 31 |
# File 'lib/lockally/models/tenant.rb', line 29 def rate_cap_per_min @rate_cap_per_min end |
#slug ⇒ Object
Returns the value of attribute slug.
20 21 22 |
# File 'lib/lockally/models/tenant.rb', line 20 def slug @slug end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/lockally/models/tenant.rb', line 24 def status @status end |
#suspended_at ⇒ Object
Returns the value of attribute suspended_at.
37 38 39 |
# File 'lib/lockally/models/tenant.rb', line 37 def suspended_at @suspended_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/lockally/models/tenant.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/lockally/models/tenant.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/lockally/models/tenant.rb', line 66 def self.attribute_map { :'id' => :'id', :'slug' => :'slug', :'display_name' => :'display_name', :'status' => :'status', :'plan' => :'plan', :'rate_cap_per_min' => :'rate_cap_per_min', :'daily_msg_quota' => :'daily_msg_quota', :'admin_email' => :'admin_email', :'created_at' => :'created_at', :'suspended_at' => :'suspended_at', :'closed_at' => :'closed_at', :'hard_delete_after' => :'hard_delete_after' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/lockally/models/tenant.rb', line 386 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/lockally/models/tenant.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/lockally/models/tenant.rb', line 94 def self.openapi_types { :'id' => :'String', :'slug' => :'String', :'display_name' => :'String', :'status' => :'String', :'plan' => :'String', :'rate_cap_per_min' => :'Integer', :'daily_msg_quota' => :'Integer', :'admin_email' => :'String', :'created_at' => :'Time', :'suspended_at' => :'Time', :'closed_at' => :'Time', :'hard_delete_after' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/lockally/models/tenant.rb', line 354 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && slug == o.slug && display_name == o.display_name && status == o.status && plan == o.plan && rate_cap_per_min == o.rate_cap_per_min && daily_msg_quota == o.daily_msg_quota && admin_email == o.admin_email && created_at == o.created_at && suspended_at == o.suspended_at && closed_at == o.closed_at && hard_delete_after == o.hard_delete_after end |
#eql?(o) ⇒ Boolean
373 374 375 |
# File 'lib/lockally/models/tenant.rb', line 373 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
379 380 381 |
# File 'lib/lockally/models/tenant.rb', line 379 def hash [id, slug, display_name, status, plan, rate_cap_per_min, daily_msg_quota, admin_email, created_at, suspended_at, closed_at, hard_delete_after].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/lockally/models/tenant.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @display_name.nil? invalid_properties.push('invalid value for "display_name", display_name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @plan.nil? invalid_properties.push('invalid value for "plan", plan cannot be nil.') end if @rate_cap_per_min.nil? invalid_properties.push('invalid value for "rate_cap_per_min", rate_cap_per_min cannot be nil.') end if @daily_msg_quota.nil? invalid_properties.push('invalid value for "daily_msg_quota", daily_msg_quota cannot be nil.') end if @admin_email.nil? invalid_properties.push('invalid value for "admin_email", admin_email cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/lockally/models/tenant.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/lockally/models/tenant.rb', line 246 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @slug.nil? return false if @display_name.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "suspended", "closing", "closed"]) return false unless status_validator.valid?(@status) return false if @plan.nil? return false if @rate_cap_per_min.nil? return false if @daily_msg_quota.nil? return false if @admin_email.nil? return false if @created_at.nil? true end |