Class: Lockally::TenantApi
- Inherits:
-
Object
- Object
- Lockally::TenantApi
- Defined in:
- lib/lockally/api/tenant_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TenantApi
constructor
A new instance of TenantApi.
-
#v1_tenant_get(opts = {}) ⇒ Tenant
Get the calling tenant Returns the tenant the presented API key belongs to.
-
#v1_tenant_get_with_http_info(opts = {}) ⇒ Array<(Tenant, Integer, Hash)>
Get the calling tenant Returns the tenant the presented API key belongs to.
-
#v1_usage_get(opts = {}) ⇒ V1UsageGet200Response
Usage snapshot Returns the tenant's current usage + cap consumption.
-
#v1_usage_get_with_http_info(opts = {}) ⇒ Array<(V1UsageGet200Response, Integer, Hash)>
Usage snapshot Returns the tenant's current usage + cap consumption.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/lockally/api/tenant_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#v1_tenant_get(opts = {}) ⇒ Tenant
Get the calling tenant Returns the tenant the presented API key belongs to.
26 27 28 29 |
# File 'lib/lockally/api/tenant_api.rb', line 26 def v1_tenant_get(opts = {}) data, _status_code, _headers = v1_tenant_get_with_http_info(opts) data end |
#v1_tenant_get_with_http_info(opts = {}) ⇒ Array<(Tenant, Integer, Hash)>
Get the calling tenant Returns the tenant the presented API key belongs to.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/lockally/api/tenant_api.rb', line 35 def v1_tenant_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TenantApi.v1_tenant_get ...' end # resource path local_var_path = '/v1/tenant' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Tenant' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TenantApi.v1_tenant_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TenantApi#v1_tenant_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#v1_usage_get(opts = {}) ⇒ V1UsageGet200Response
Usage snapshot Returns the tenant's current usage + cap consumption. Designed for poll-based alerting on the integrator side (e.g. "warn when daily quota is 80% used"). Refreshed live from Postgres — there is no cache, so callers should poll at most once per minute.
83 84 85 86 |
# File 'lib/lockally/api/tenant_api.rb', line 83 def v1_usage_get(opts = {}) data, _status_code, _headers = v1_usage_get_with_http_info(opts) data end |
#v1_usage_get_with_http_info(opts = {}) ⇒ Array<(V1UsageGet200Response, Integer, Hash)>
Usage snapshot Returns the tenant's current usage + cap consumption. Designed for poll-based alerting on the integrator side (e.g. "warn when daily quota is 80% used"). Refreshed live from Postgres — there is no cache, so callers should poll at most once per minute.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/lockally/api/tenant_api.rb', line 92 def v1_usage_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TenantApi.v1_usage_get ...' end # resource path local_var_path = '/v1/usage' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/problem+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'V1UsageGet200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"TenantApi.v1_usage_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TenantApi#v1_usage_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |